/*
 {$BRAND_NAME`}
 Copyright (c) ocProducts, 2004-2012
*/

/*
=========================
===Overridden Elements===
=========================
*/

html, body {
	border: 0;
	{+START,IF,{$MOBILE}}
		word-wrap: break-word;
	{+END}
}

body, textarea, input, td, th {
	font-family: 'Verdana', 'Arial', 'Helvetica', sans-serif;
}

tt, kbd, samp {
	font-weight: bold;
}

abbr,acronym {
	border-bottom: 1px dotted; /* For Safari, which does not have it by default */
}

{+START,IF,{$VALUE_OPTION,html5}}
	/* Reapply default styles non-HTML5-aware browsers */
	aside,footer,header,nav,hgroup,article {
		display: block;
	}
{+END}

textarea, input {
	font-size: 1em;
}

input[type="text"]:focus, input[type="password"]:focus {
	background: url('{$IMG;,keyboard}') right center no-repeat white;
}

input[type="text"],input[type="password"],input[type="color"],input[type="email"],input[type="number"],input[type="range"],input[type="search"],input[type="tel"],input[type="url"],textarea,select { /* Normally a browser default, but gets inherited on some phones */
	background: white;
}

a:link, a:visited, a:hover, a:active {
	text-decoration: underline;
}
a:link, .buttonhyperlink {
	color: #123d7b; /* {$,a.link, 73% (seed sat_to 85) + 27% !W/B} */
	-webkit-transition: color 1s linear;
	-moz-transition: color 1s linear;
	-o-transition: color 1s linear;
}
a:visited {
	color: #113871; /* {$,wizard, 67% (seed sat_to 85) + 33% !W/B} */
	-webkit-transition: color 1s linear;
	-moz-transition: color 1s linear;
	-o-transition: color 1s linear;
}
a:hover, .buttonhyperlink:hover {
	-webkit-transition: color 1s linear;
	-moz-transition: color 1s linear;
	-o-transition: color 1s linear;
	color: #051225; /* {$,a.hover, 30% a.link + 70% !W/B } */
}

code {
	font-size: 1em;
}

/* An iframe screen */
.opens_below h1 {
	display: none;
}

h1 {
	font-weight: normal;
	font-family: "Georgia", "Times New Roman", "Times", serif;
	font-size: 1.9em;
	color: #325180; /* {$,wizard, 76% seed + 24% !W/B} */
	border-bottom: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
}

h2 {
	font-size: 1.3em;
	color: #325180; /* {$,wizard, 76% seed + 24% !W/B} */
	border-bottom: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
	font-weight: normal;
	margin-top: 1em;
}

h3 {
	font-size: 1.1em;
	color: #325180; /* {$,wizard, 76% seed + 24% !W/B} */
	border-bottom: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
	font-weight: normal;
}

h3 a:link,
h3 a:active,
h3 a:visited,
h3 a:hover {
	text-decoration: none;
}

h4 {
	font-size: 1em;
	font-weight: bold;
}

table {
	vertical-align: top;
	font-size: 1em;
}

td, table th.de_th {
	vertical-align: top;
	color: #0d1522; /* {$,wizard, 20% seed + 80% !W/B} */
	font-size: 1em;
	font-weight: normal;
}

th, .fake_th {
	vertical-align: top;
	background-color: #a2b6d5; /* {$,th.bgcolor, 60% sb_color + 40% seed} */
	font-size: 0.85em;
	color: #313740; /* {$,wizard, 30% th.bgcolor + 70% !W/B} */
	font-weight: bold;
	text-align: center;
}

.de_th { /* {$,Allows structurally accurate but visually non-interfering markup}  */
	text-align: {!en_left};
	background-color: transparent;
	font-weight: normal;
	border: 0;
}

.de_th a {
	font-weight: normal;
}

hr {
	height: 0;
	border: 0;
	border-bottom: 2px dotted #a2b6d5; /* {$,wizard, 60% sb_color + 40% seed} */
}

img {
	display: inline;
	border: 0;
}

iframe {
	padding: 0;
	margin: 0;
	border: 0;
}

hr { /* Fixes difference with Opera */
	text-align: left;
}

/*input[type="text"],textarea {  So Comcode can be typed
	unicode-bidi: bidi-override;
	direction: ltr;
}*/

#htmlarea input[type="text"], #htmlarea textarea {
	unicode-bidi: normal;
	direction: {!dir};
}

form { /* For IE6 */
	margin-bottom: 0;
}

{+START,IF,{$MOBILE}}
	select {
		max-width: 100px;
	}
{+END}

/*
=========================
=====Global interface====
=========================
*/

/* {$,washed_out, 10% (seed sat_to 85) + 90% W/B} */

/* {$,lgradcolor, 67% (seed sat_to 95) + 33% FFFFFF} */ /* {$,We always want the light source coming from the top} */
/* {$,dgradcolor, 95% (seed sat_to 65) + 5% 000000} */ /* {$,We always want the shadows at the bottom} */
/* {$,bordcolor, 60% (seed sat_to 93) + 40% !W/B} */
/* {$,lightborder, 33% seed + 67% W/B} */
/* {$,bgcol, 15% seed + 85% W/B} */
/* {$,ltgradcolor, 67% (seed sat_to 135) + 33% FFFFFF} */  /* {$,We always want the light source coming from the top} */
/* {$,dtgradcolor, 95% (seed sat_to 25) + 5% 000000} */ /* {$,We always want the shadows at the bottom} */
/* {$,sb_color, 15% seed + 85% W/B} */

/* {$,ocf_row2, 11% seed + 89% W/B}*/

/* {$,comcode_quote_left, 48% comcode_quote_right + 52% W/B} */
/* {$,comcode_quote_right, 100% comcode_code_h4} */

/* {$,zg_peak,90% zg_top + 10% W/B} */
/* {$,zg_top,48% (seed sat_to 98) + 52% FFFFFF} */
/* {$,zg_bot,97% (seed sat_to 71) + 3% 000000} */

/* {$,medborder.border, 95% (seed sat_to 33) + 5% !W/B} */

/* {$,ocfpostindicator, 65% (seed sat_to 100) + 35% W/B} */
/* {$,ocfredirectindicator, 65% (seed sat_to 100) + 35% W/B + 000038 - 061600} */

/* {$,a.link__dark, 63% (seed sat_to 85) + 37% !W/B} */
/* {$,a.hover__dark, 20% a.link + 80% !W/B } */

/* {$,special_borderer, 76% seed + 24% !W/B} */
/* {$,special_middle, 45% (seed sat_to 85) + 65% !W/B} */

.re_body, #htmlarea {
	margin: 0;
	font-size: 0.8em;
}

/* Consider .re_body as 'body': it is just we cannot put our styles directly on body because sometimes this gets used in things we should not mess with such as the WYSIWYG editors frame (which is #htmlarea) and e-mails */
.re_body {
	padding: 0 !important;
	color: #0d1522; /* {$,wizard, 20% seed + 80% !W/B} */
	background: #FFFFFF; /* {$,wizard, 100% W/B} */
}

{+START,IF,{$CONFIG_OPTION,fixed_width}}{+START,IF,{$NOT,{$MOBILE}}}
	#main_website { /* #main_website targets only the main site screen, avoiding frames etc */
		background-color: #e3eaf6 !important; /* {$,wizard, 11% (seed sat_to 100) + 89% W/B} */

		/* Want to change the tiled background?
			Try this Google search to get image ideas http://www.google.co.uk/search?tbm=isch&q=tile+background
			Find how to edit the referenced "outer-background" theme image by doing an Admin Zone search for "outer-background"
		*/
		background: url('{$IMG;,outer-background}');
	}
	#main_website #body_inner {
		width: 980px;
		position: relative;
		margin: 0 auto 0 auto;
		border-left: 1px solid #8ba4ca; /* {$,wizard, 61% seed + 39% W/B} */
		border-right: 1px solid #8ba4ca; /* {$,wizard, 61% seed + 39% W/B} */
		border-bottom: 1px solid #8ba4ca; /* {$,wizard, 61% seed + 39% W/B} */
		-webkit-box-shadow: 0 0 30px #6b81a1; /* {$,wizard, 100% medborder.border} */
		-moz-box-shadow: 0 0 30px #6b81a1; /* {$,wizard, 100% medborder.border} */
		box-shadow: 0 0 30px #6b81a1; /* {$,wizard, 100% medborder.border} */
	}
{+END}{+END}

.global_top {
	background-color: #e3e9f2; /* {$,topcolor, 100% bgcol } */
	{+START,IF,{$NOT,{$CONFIG_OPTION,fixed_width}}}
		-webkit-box-shadow: 0 0 2px 2px #426aa9; /* {$,wizard, 100% seed} */
		-moz-box-shadow: 0 0 2px 2px #426aa9; /* {$,wizard, 100% seed} */
		box-shadow: 0 0 2px 2px #426aa9; /* {$,wizard, 100% seed} */
	{+END}
}

.global_top h1 {
	margin: 0;
	{+START,IF,{$MOBILE}}
		width: 100%;
		float: left;
		text-align: center;
	{+END}
}

{+START,IF,{$NOT,{$MOBILE}}}
	.logo {
		float: left;
	}

	/*
	Commented out by default.
	If you enable it will turn off the standard logo and replace it with a big header image.
	Don't enable if banners addon is still installed

	Find how to edit the referenced "header" theme image by doing an Admin Zone search for "header"
	*/
	/*
	.logo_outer {
		margin-bottom: 8px;
		width: 980px;
		height: 100px;
		float: left;
		background: url('{$IMG;,header}') no-repeat !important;
	}

	.logo_outer * {
		display: none;
	}

	#global_zones {
		margin-top: 99px !important;
	}
	*/
{+END}

#global_zones {
	{+START,IF,{$MOBILE}}
		text-align: center !important;
		margin: 0 auto;
		padding: 8px 0px 9px 0;
		font-size: 0.95em;
	{+END}
	{+START,IF,{$NOT,{$MOBILE}}}
		text-align: right;
		margin-top: 59px;
		padding: 6px 5px 8px 0;
		background: url('{$IMG;,zone_gradient}') repeat-x;
	{+END}
	min-height: 15px;
	font-weight: bold;
	color: #edf2f9; /* {$,wizard, 15% zg_top + 85% W/B} */
	background-color: #426aa9; /* {$,wizard, 100% seed} */
	background-position: left bottom;
}

.global_banner {
	position: absolute;
	top: 0;
	right: 0;
}

.text_banner {
	width: 13.5em;
	font-family: 'Arial', sans-serif;
	background-color: white;
}

.text_banner a {
	font-size: 1.4em;
}

.text_banner_l_text {
	color: #008000; /* {$,wizard, 100% 008000} */ /* Google adwords style */
	font-size: 0.9em;
}

/* This is applied to the screen title, which is specially included on each screen; in the case of Comcode pages it is the first level 1 title. The screen title is by default an h1, but we define the styles separately so we can style this special title independently (there are lots of cool things we could do to it) */
.main_page_title {
	margin-top: 0.35em;
	margin-bottom: 0.8em;
	min-width: 300px;
}

.breadcrumbs {
	padding: 5px 0 0 0;
	{+START,IF,{$NOT,{$MOBILE}}}
		float: {!en_right};
		margin-left: 5px;
	{+END}
	zoom: 1;
}

.breadcrumbs abbr {
	white-space: nowrap;
}

.breadcrumbs_always {
	font-weight: bold;
}

.breadcrumbs_img {
	vertical-align: middle;
	margin-{!en_right}: 4px;
}

.page_title_tagline, .page_subtitle_tagline {
	font-size: 0.8em;
}

.page_title_tagline {
	padding-bottom: 20px;
	margin-top: -1.5em;
	color: #444649; /* {$,wizard, 30% sb_color + 70% !W/B} */
}

.page_subtitle_tagline {
	margin: -8px 0 0 19px;
}

.global_div {
	padding-bottom: 15px;
}

#global_surround {
	min-height: 450px;
}

.fake_middle_continuation, #main_website #body_inner {
	background-color: #ffffff; /* {$,maincolor, 100% W/B} */

	/* Want to set a tiled background?
		Uncomment the code below
		Try this Google search to get image ideas http://www.google.co.uk/search?tbm=isch&q=tile+background
		Find how to edit the referenced "inner-background" theme image by doing an Admin Zone search for "inner-background"
	*/
	/*background: url('{$IMG;,inner-background}');*/
}

.global_middle {
	padding: 5px;
}

#global_middle_ph {
	padding-bottom: 6px; /* {$,Stops margin collapsing} */
	width: 100%; /* Needed for IE7 */
}

#popup_spacer {
	padding: 20px;
}

#popup_spacer h2 {
	margin-top: 0;
}

#panel_left {
	float: {!en_left};
}

#panel_right {
	float: {!en_right};
}

#panel_left, #panel_right {
	padding-bottom: 10px;
}

.fp_col_block {
	{+START,IF,{$NOT,{$MOBILE}}}
		width: 48%;
	{+END}
	{+START,IF,{$MOBILE}}
		margin: 0.5em 0;
		width: 100%;
	{+END}
}

.global_message {
	padding: 4px 4px 8px 4px;
}

.fake_middle_continuation {
	padding: 1px; /* {$,Needed to force border draw of inner-contents} */
}

/* fake_middle_continuation is defined to make it easy for us to reapply the same styling that goes to global_middle to something else such as the contents of an iframe */
.global_middle, .fake_middle_continuation {
}

.global_side {
	word-wrap: break-word;
	padding-top: 1em;
}

.global_side .standardbox_wrap_panel {
	font-size: 0.9em;
}

.global_side h2 {
	font-size: 1.3em;
	border-bottom: 1px solid;
	text-transform: lowercase;
	font-weight: normal;
	width: 50%;
	padding-{!en_left}: 10px;
	margin-{!en_left}: 10px;
}

#helper_panel_toggle {
	outline: 0;
	float: {!en_right};
	margin: 11px 0;
}

.top_level_wrap .horiz_help_panel { /* {$,Long definition to force precedence} */
	width: 100% !important;
	float: none !important;
	overflow: auto;
	outline: 0;
}

.horiz_help_panel #help {
	width: {$?,{$MOBILE},315,380}px;
	float: {!en_left};
}

.horiz_help_panel #help_tutorial {
	width: {$?,{$MOBILE},315,380}px;
	float: {!en_left};
}

.horiz_help_panel #global_helper_panel_pic {
	display: none;
}

.horiz_help_panel .global_helper_panel_html {
	display: none;
}

.horiz_help_panel .global_helper_panel {
	padding: 0;
	height: auto;
	position: static;
}

.horiz_help_panel .global_helper_panel_text {
	position: static;
}

.global_helper_panel_wrap {
	border: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
	background-color: #eaeff6; /* {$,wizard, 100% ocf_row2} */
	margin-left: 10px;
	overflow: hidden;
	position: relative;
	zoom: 1; /* Fixes scrollbar due to IE6 double border counting bug */
}

.global_helper_panel {
	padding: 15px;
	position: relative;
	font-size: 0.85em;
}

.global_helper_panel_text {
	z-index: 4;
	position: relative;
}

.global_helper_panel_text_over {
}

.global_helper_panel_pic {
	opacity: 0.2;
	position: absolute;
	z-index: 2;
	bottom: 0;
}

.global_helper_panel_html {
	position: absolute;
	/*bottom: -270px;*/
	z-index: 2;
	width: {$?,{$MOBILE},315,390}px;
}

.login_page {
	background: url('{$IMG;,background_image}') no-repeat 20px 44px;
	padding: 5px;
}

.important_notification {
	text-align: center;
}

.global_notification {
	margin: 3px 0;
}

.global_notification strong {
	text-shadow: 1px 1px 1px #4b5a71; /* {$,wizard, 70% medborder.border + 30% !W/B} */
	font-weight: normal;
}

.global_notification img {
	margin-top: -3px;
	margin-{!en_right}: 5px;
}

.site_special_message {
	padding: {$?,{$MOBILE},30,100}px 0;
	text-align: center;
}

.ssm_warn {
	background: url('{$IMG;,am_icons/warn_large}') right 20px no-repeat;
	{+START,IF,{$NOT,{$MOBILE}}}
		padding: 100px 220px 100px 30px;
	{+END}
	{+START,IF,{$MOBILE}}
		padding-bottom: 170px;
	{+END}
}

.expanded_advice {
	padding: 0 {$?,{$MOBILE},0,230px} 200px 0;
}

.ssm_inform {
	background: url('{$IMG;,am_icons/inform_large}') right 20px no-repeat;
	{+START,IF,{$NOT,{$MOBILE}}}
		padding: 100px 220px 100px 30px;
	{+END}
	{+START,IF,{$MOBILE}}
		padding-bottom: 170px;
	{+END}
}

.site_special_message_inner, .site_special_message_alt_inner {
	display: inline-block;
}

.closed_site_special_message {
	margin: {$?,{$MOBILE},30px 2em,100px auto};
	{+START,IF,{$NOT,{$MOBILE}}}
		width: 600px;
	{+END}
	text-align: center;
}

.bottom {
	background-color: #6b81a1; /* {$,wizard, 100% medborder.border} */

	color: #ffffff; /* {$,wizard, 100% W/B} */
	padding: 10px 0;
	{+START,IF,{$NOT,{$CONFIG_OPTION,fixed_width}}}
		-webkit-box-shadow: 0 0 2px 2px #8ba4ca; /* {$,footer_bg, 61% seed + 39% W/B} */
		-moz-box-shadow: 0 0 2px 2px #8ba4ca; /* {$,footer_bg, 61% seed + 39% W/B} */
		box-shadow: 0 0 2px 2px #8ba4ca; /* {$,footer_bg, 61% seed + 39% W/B} */
	{+END}
	{+START,IF,{$MOBILE}}
		text-align: center;
	{+END}
}

.bottom .buttonhyperlink,
.bottom a:link,
.bottom a:visited,
.bottom a:active,
.bottom .linkcolor {
	color: #000000; /* {$,wizard, 100% !W/B} */
}

.bottom a:hover {
	color: #FFFFFF !important; /* {$,wizard, 100% W/B} */
}

.bottom_under {
	padding: 0 10px;
}

.global_bottom {
	{+START,IF,{$NOT,{$MOBILE}}}
		float: {!en_left};
	{+END}
	display: inline-block; /* For IE6 - force shrink to width */
}

.global_bottom img {
	vertical-align: middle;
}

.global_bottom_button_ref_point {
	position: absolute;
}

#special_page_type {
	width: 17em;
}

.global_flagrant {
	{+START,IF,{$NOT,{$MOBILE}}}
		float: {!en_right};
	{+END}
	font-size: .9em;
	color: #dbe6f7; /* {$,wizard, 35% footer_bg + 65% W/B} */
	font-weight: bold;
	padding-bottom: 4px;
	text-shadow: 2px 2px 2px #6b81a1; /* {$,wizard, 100% medborder.border} */
}

.invisible_ref_point {
	position: absolute;
	width: 0px;
}

.global_copyright {
	{+START,IF,{$NOT,{$MOBILE}}}
		text-align: center;
	{+END}
	font-size: 0.85em;
}

.global_minilinks {
	padding-top: 3px;
	font-size: 0.9em;
	white-space: nowrap; /* Stops logout link wrapping around in Firefox 3.6 */
}

.global_minilinks a {
	white-space: nowrap;
	{+START,IF,{$MOBILE}}
		padding: 4px;
	{+END}
}

.global_minilinks a:hover {
	color: #97aed0; /* {$,wizard, 10% W/B + 90% footer_bg} */
}

{+START,IF,{$MOBILE}}
	/* On mobiles we want maximum fluidity */

	table, table.do_next_section {
		table-layout: auto !important;

		/* Allows wrapping */
		overflow-x: visible !important;
		overflow-y: visible !important;
	}
	col {
		width: auto !important;
	}
	* {
		white-space: normal !important;
		word-wrap: break-word !important;
	}
{+END}

/*
=========================
=====Software Styles=====
=========================
*/

.standardbox_spaced {
	padding: 0 5px 5px 5px;
}

.standardbox_wrap_classic {
	border: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */

	/* To prevent horizontal overlapping with floats */
	overflow: auto;
	outline: 0;
}

.standardbox_wrap_panel {
	margin: 5px 5px 0 5px;
}

.standardbox_wrap_panel img {
	max-width: 98%;
}

{+START,IF,{$MOBILE}}
	.standardbox_wrap_panel {
		float: left;
		width: 145px;
	}
{+END}

/* Basic styling */
.standardbox_wrap_panel {
	border: 1px solid #8ba4ca; /* {$,wizard, 61% seed + 39% W/B} */
	zoom: 1; /* IE6 does not display bottom borders if this is not here */
}
/* Precedence (!important) for browsers that support the > and + selectors; precedence stops it relying on .interlock being right */
html>body .standardbox_wrap_panel { /* Runs before the below selector, the best we can to given we don't have multiple levels of important or negation in CSS; it's needed to take precedence over the .interlock selector */
	border-top: 1px solid #8ba4ca !important; /* {$,wizard, 61% seed + 39% W/B} */
	margin-top: 5px !important;
}
{+START,IF,{$NOT,{$MOBILE}}}
	.standardbox_wrap_panel + .standardbox_wrap_panel, html>body.fake_middle_continuation div.interlock {
		border-top: 0px !important;
		margin-top: 0 !important;
	}
	/* Otherwise (IE6) will use the following, which depends on Tempcode correctly tracking the template inclusion orders via .interlock */
	.interlock {
		border-top: 0px;
		margin-top: 0;
	}
{+END}

.standardbox_wrap_curved {
	text-align: left; /* fixes IE bug */
}

.standardbox_curved_ie_hack {
	line-height: 0px;
}

.standardbox_meta_classic {
	font-style: italic;
	font-size: 0.8em;
	border-bottom: 1px solid;
}

.standardbox_title_curved, .standardbox_title_curved_iesucks {
	padding-top: 2px;
	margin-top: 0;
	margin-bottom: 0;
	{+START,IF,{$MOBILE}}
		min-height: 18px;
	{+END}
	{+START,IF,{$NOT,{$MOBILE}}}
		height: 18px;
	{+END}
	border-top: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
	border-bottom: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
}

.standardbox_title_curved {
	margin-left: 6px;
	margin-right: 6px;
}

.standardbox_title_curved_iesucks {
}

.standardbox_curved_nontitle_middle, .standardbox_curved_bottom_middle {
	margin-left: 6px;
	margin-right: 6px;
	font-size: 0em;
	line-height: 1px; /*0px causes gap on IE7*/
	background-color: #eaeff6; /* {$,wizard, 100% ocf_row2} */
	height: 4px;
}

.standardbox_curved_nontitle_middle {
	border-top: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
}

.standardbox_curved_bottom_middle {
	border-bottom: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
}

.standardbox_curved_title_left {
	background: url('{$IMG;,standardboxes/title_left}') 0 0 no-repeat;
}

.standardbox_curved_nontitle_left {
	background: url('{$IMG;,standardboxes/nontitle_left}') 0 0 no-repeat;
}

.standardbox_curved_bottom_left {
	background: url('{$IMG;,standardboxes/bottom_left}') 0 100% no-repeat;
}

.standardbox_curved_title_right {
	background: url('{$IMG;,standardboxes/title_right}') 100% 0 no-repeat;
}

.standardbox_curved_nontitle_right {
	background: url('{$IMG;,standardboxes/nontitle_right}') 100% 0 no-repeat;
}

.standardbox_curved_bottom_right {
	background: url('{$IMG;,standardboxes/bottom_right}') 100% 100% no-repeat;
}

.standardbox_iesucks_curved_left, .standardbox_iesucks_curved_right {
	width: 5px;
}

.standardbox_iesucks_curved_left {
	border-{!en_left}: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
}

.standardbox_iesucks_curved_right {
	border-{!en_right}: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
}

.standardbox_iesucks_curved_rule {
}

.standardbox_curved {
	margin: 0;
}

.standardbox_inner_curved, .standardbox_iesucks {
	background-color: #eaeff6; /* {$,wizard, 100% ocf_row2} */
}

.standardbox_classic, .standardbox_wrap_classic .standardbox_links_classic {
	margin: 0;

	/* Want to change the tiled background?
		Try this Google search to get image ideas http://www.google.co.uk/search?tbm=isch&q=tile+background
		Find how to edit the referenced "block-background" theme image by doing an Admin Zone search for "block-background"
	*/
	background: url('{$IMG;,block-background}') #eaeff6; /* {$,wizard, 100% ocf_row2} */
}

.standardbox_t_panel, .standardbox_nt_panel {
	margin: 0px;
}

.standardbox_t_panel {
	background-color: #eaeff6; /* {$,wizard, 100% ocf_row2} */
}

.standardbox_nt_panel {
	background-color: #e3eaf6; /* {$,wizard, 11% (seed sat_to 100) + 89% W/B} */
}

.standardbox_inner_curved {
	border: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
	border-top: 0px;
	border-bottom: 0px;
}

.tabletitle_internal {
	padding: 2px;
}

.standardbox_title_classic, .tabletitle_internal, .standardbox_title_med, .standardbox_title_curved, .standardbox_title_curved_iesucks {
	/* Structure */
	background-color: #426aa9; /* {$,wizard, 100% seed} */
	background-image: url('{$IMG;,standardboxes/title_gradient}');
	background-repeat: repeat-x;

	/* Text */
	color: #ffffff; /* {$,wizard, 100% W/B} */
	text-align: center;
	font-weight: bold;
	text-decoration: none;
	font-size: 1em;
}

h3.standardbox_title_classic {
	border-bottom: 0;
}

.standardbox_title_classic a, .tabletitle_internal a, .standardbox_title_med a, .standardbox_title_curved a, .standardbox_title_curved_iesucks a {
	color: #ffffff !important; /* {$,wizard, 100% W/B} */
}

.standardbox_title_panel {
	/* Structure */
	border-bottom: 1px solid #8ba4ca !important; /* {$,wizard, 61% seed + 39% W/B} */
	background-color: #e3eaf6 !important; /* {$,wizard, 11% (seed sat_to 100) + 89% W/B} */

	/* Text */
	padding-top: 0.6em !important;
	padding-bottom: 0.6em !important;
	padding-{!en_left}: 5px !important;
	color: #0d1522 !important; /* {$,wizard, 20% seed + 80% !W/B} */
	font-weight: bold !important;
	font-size: 1em !important;
	text-transform: none !important;
	width: auto !important;
	margin-left: 0 !important;
}

.menu_block .standardbox_title_panel {
	background-color: #426aa9 !important; /* {$,wizard, 100% seed} */
	color: white !important;
	background-image: url('{$IMG;,standardboxes/title_gradient}');
	background-repeat: repeat-x;
}

.standardbox_title_panel, .standardbox_title_classic, .tabletitle_internal, .standardbox_title_med {
	margin: 0;
}

.standardbox_title_light, .standardbox_main_classic .standardbox_title_med {
	/* Structure */
	background-image: none;
	background-color: #a2b6d5; /* {$,wizard, 60% sb_color + 40% seed} */
	margin: 0;

	/* Text */
	color: #313740; /* {$,wizard, 30% th.bgcolor + 70% !W/B} */
	text-align: center;
	font-weight: bold;
	font-size: 1em;
}

.standardbox_title_classic, .standardbox_title_med, .standardbox_title_light {
	padding-top: 0.35em;
	padding-bottom: 0.35em;
}

.no_stbox_padding .standardbox_main_classic {
	padding: 0;
}

.overlay .dottedborder_huge_a, .overlay .dottedborder_barrier_a_nonrequired, .overlay .dottedborder_barrier_b_nonrequired, .overlay .dottedborder_divider, .overlay .dottedborder_divider_continue, .overlay .no_stbox_padding .forcedottedborder, .overlay .dottedborder {
	border: 0;
}

.no_stbox_padding .dottedborder {
	border: 0;
}

.no_stbox_padding .dottedborder td {
	border-right: 0;
	border-top: 0;
}

.no_stbox_padding .dottedborder th {
	border-{!en_left}: 0;
	border-top: 0;
}

.no_stbox_padding .dottedborder thead tr:last-child td,
.no_stbox_padding .dottedborder thead tr:last-child th {
	border-bottom: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
}

.no_stbox_padding .forcedottedborder  {
	padding: 0;
}

.no_stbox_padding .forcedottedborder div {
	border-bottom: 1px dotted #6b81a1; /* {$,wizard, 100% medborder.border} */
	padding: 5px 5px 15px 5px;
}

.standardbox_main_classic {
	{+START,IF,{$MOBILE}}
		padding: 2px;
	{+END}
	{+START,IF,{$NOT,{$MOBILE}}}
		padding: 3px 6px;
	{+END}
}

.standardbox_links_classic {
	bottom: 0;
	padding: 3px 6px;
}

.standardbox_custom_wide {
	width: 100%;
}

.standardbox_links_classic a:link, .standardbox_title_panel a:link, .standardbox a:link, .standardbox_main_classic a:link {
	color: #123d7b; /* {$,wizard, 73% (seed sat_to 85) + 27% !W/B} */
}
.standardbox_links_classic a:visited, .standardbox_title_panel a:visited, .standardbox a:visited, .standardbox_main_classic a:visited {
	color: #113871; /* {$,wizard, 67% (seed sat_to 85) + 33% !W/B} */
}
.standardbox_links_classic a:hover, .standardbox_title_panel a:hover, .standardbox a:hover, .standardbox_main_classic a:hover {
	color: #9C202F; /* {$,wizard, 100% a.hover}*/
}

.standardbox_tray {
	float: {!en_right};
	padding: 0 5px !important;
}

/* {$,lightborder is very similar to a standard-box, but more like a 'featured island' (less box-like, more fluid). It is also used for the 'light' box} */
.lightborder {
	border: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
	background-color: #eaeff6; /* {$,wizard, 100% ocf_row2} */

	/* To prevent horizontal overlapping with floats */
	overflow: hidden;
	outline: 0;
}

/* {$,dottedborder is for input forms usually} */
.dottedborder {
	border-collapse: collapse;
	border: 1px dotted #6b81a1; /* {$,wizard, 100% medborder.border} */
}

.dottedborder_barrier,
.dottedborder_barrier_a_nonrequired,
.dottedborder_barrier_b_nonrequired,
.dottedborder_barrier_a_required,
.dottedborder_barrier_b_required,
.dottedborder_huge_a,
.dottedborder_divider,
.dottedborder_divider_continue {
	border: 1px dotted #6b81a1; /* {$,wizard, 100% medborder.border} */
	padding: {$?,{$MOBILE},2,5}px;
}

.dottedborder select {
	max-width: 100%;
}

.thick_border .dottedborder_barrier_b_nonrequired {
	border-top-width: 3px;
}

.dottedborder_huge_a, .dottedborder_barrier_a_nonrequired, .dottedborder_barrier_b_nonrequired, .dottedborder_divider, .dottedborder_divider_continue, .no_stbox_padding .forcedottedborder {
	background-color: #eaeff5; /* {$,barrier_a, 72% bgcol + 28% W/B} */
}

.zebra_0 .dottedborder_barrier_b_nonrequired {
	background-color: #d9e1ee; /* {$,wizard, 20% seed + 80% W/B} */
}

.zebra_1 .dottedborder_barrier_b_nonrequired {
	background-color: #eaeff6; /* {$,wizard, 100% ocf_row2} */
}

.dottedborder_barrier_a_required, .dottedborder_barrier_a_required .lightborder, .dottedborder_barrier_b_required {
	background-color: #e9dede; /* {$,barrier_a_required, 95% (barrier_a hue_to 0) + 5% !W/B} */
}

.filledin .dottedborder_barrier_a_required, .filledin .dottedborder_barrier_a_required .lightborder, .filledin .dottedborder_barrier_b_required {
	background-color: #eaeff5; /* {$,barrier_a, 72% bgcol + 28% W/B} */
}

.dottedborder_divider_continue {
	border-top: 0 !important;
}

.dottedborder_divider {
	border-bottom: 0 !important;
}

.dottedborder_huge_a {
	border-bottom: 0px;
}
.dottedborder_huge_b {
	border-top: 0px;
}

#word_count {
	float: right;
	font-size: 0.8em;
	padding: 4px;
}

/* medborder is similar to lightborder; in fact, there isn't any rule as to when to use each: it is just artistic */
.medborder,
.results_browser a,
.results_browser span,
.results_launcher a,
.results_launcher span {
	{+START,IF,{$NOT,{$MOBILE}}}
		border: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
	{+END}
	{+START,IF,{$MOBILE}}
		border: 2px solid #c1cee3; /* {$,wizard, 100% lightborder} */
	{+END}
	background-color: #eaeff6; /* {$,wizard, 100% ocf_row2} */
}

.boxes_together_follower { /* boxes_together_follower is just for IE6, which does not support +, we have to go to extra effort in our templates to add this class */
	border-top: 0 !important;
}
.boxes_together + .boxes_together {
	border-top: 0;
}

.results_browser a:hover, .results_launcher a:hover {
	background-color: #c2d1e5 !important; /* {$,hover_bg, 93% (mm_c_tab sat_to 15) + 7% !W/B} */
}

{+START,IF,{$NOT,{$MOBILE}}}
	.results_browser a,
	.results_browser span,
	.results_launcher a,
	.results_launcher span {
		margin-{!en_left}: -1px;
	}
{+END}

.medborder_collapse {
	border-collapse: collapse;
}

.medborder_detailhead {
	font-size: 0.8em;
	color: #325180; /* {$,wizard, 76% seed + 24% !W/B} */
	border-bottom: 1px solid;
	{+START,IF,{$NOT,{$MOBILE}}}
		width: 300px;
	{+END}
	max-width: 100%;
	padding-{!en_left}: 5px;
	padding-bottom: 0.5em;
}

.medborder_detailhead a {
	text-decoration: none;
	color: #0d2d5d; /* {$,wizard, 55% (seed sat_to 86) + 45% !W/B} */
}

.medborder_detailhead a:hover {
	color: #9C202F; /* {$,wizard, 100% a.hover}*/
}

.global_side .medborder_detailhead_wrap {
	padding: 0;
}

.global_side .medborder_detailhead {
	border-bottom: 0;
	padding-left: 0;
	padding-top: 5px;
}

.medborder_box {
	{+START,IF,{$MOBILE}}
		padding: 2px;
	{+END}
	{+START,IF,{$NOT,{$MOBILE}}}
		padding: 5px;
	{+END}
}

.global_side .medborder_box {
	padding: 1px;
}

.medborder_detailhead_wrap {
	padding: 10px;
}

.help_jumpout {
	float: {!en_left};
	margin-{!en_right}: 5px;
	margin-top: -2px;
}

.solidborder {
	border-collapse: collapse;
}

.solidborder, .solidborder td, .solidborder th {
	border: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
}

/* Undo for nested tables from WYSIWYG */
.solidborder table[border="0"] td, .solidborder table[border="0"] th {
	border: 0;
}

.do_next_page_question {
	font-size: 1em;
	{+START,IF,{$NOT,{$MOBILE}}}
		margin-bottom: 50px;
	{+END}
}

.do_next_section_wrap {
	padding-bottom: 10px;
}

.do_next_section {
	margin: 0 auto;
	font-size: 0.9em;
	table-layout: fixed !important;
	{+START,IF,{$NOT,{$MOBILE}}}
		width: 543px;
	{+END}
	{+START,IF,{$MOBILE}}
		width: 100%;
	{+END}
	border-collapse: collapse;
}

.do_next_section td {
	padding: 0;
}

.do_next_section table td {
	padding: 6px;
}

.do_next_section_inner {
	background-color: #e3e9f2; /* {$,wizard, 100% sb_color } */
}

.do_next_section table {
	border-collapse: collapse;
}

.do_next_item_spacer {
	border: 1px;
}

.do_next_item, .do_theme_item {
	background-color: #eaeff6; /* {$,do_next_item, 100% ocf_row2 } */
}

.do_next_item, .do_next_item_hover {
	width: 25%;
	cursor: pointer;
}

.do_theme_item, .do_theme_item_hover {
	width: 16%;
}

.do_next_item, .do_next_item_hover, .do_theme_item, .do_theme_item_hover {
	border: 1px dotted #6b81a1; /* {$,wizard, 100% medborder.border} */
	text-align: center;
	font-size: 0.9em;
	padding-bottom: 5px;
	-webkit-transition: background-color 0.5s linear;
	-moz-transition: background-color 0.5s linear;
	-o-transition: background-color 0.5s linear;
}

.do_next_item_hover, .do_theme_item_hover {
	background-color: #E6D8DF; /* {$,wizard, 92% (do_next_item hue_to 92) + 8% !W/B} */
}

.do_next_item_hover {
	border-style: solid;
}

.do_next_icon {
	width: 45px;
	height: 45px;
}

.do_next_pretty_title_left {
	width: 21px;
	background-image: url('{$IMG;,donext/titleleft}');
	background-repeat: no-repeat;
	background-position: bottom right;
}

.do_next_pretty_title {
	height: 10px;
	color: #ffffff; /* {$,wizard,100% W/B} */
	background-color: #5985c7; /* {$,donextbordercolor, 65% (seed sat_to 100) + 35% W/B} */
	text-align: center;
}

.do_next_pretty_pad {
	width: 0;
}

.do_next_pretty_title_right {
	width: 21px;
	background-image: url('{$IMG;,donext/titleright}');
	background-repeat: no-repeat;
	background-position: bottom left;
}

.do_next_pretty_top_left {
	height: 10px;
	background-repeat: no-repeat;
	background-image: url('{$IMG;,donext/topleft}');
}

.do_next_pretty_top {
	height: 10px;
	background-repeat: repeat-x;
	background-image: url('{$IMG;,donext/topcent}');
}

.do_next_pretty_top_right {
	height: 10px;
	background-repeat: no-repeat;
	background-image: url('{$IMG;,donext/topright}');
}

.do_next_pretty_mid_left {
	background-repeat: repeat-y;
	background-image: url('{$IMG;,donext/midleft}');
}

.do_next_pretty_mid_right {
	background-repeat: repeat-y;
	background-image: url('{$IMG;,donext/midright}');
}

.do_next_pretty_bottom_left {
	height: 10px;
	background-repeat: no-repeat;
	background-image: url('{$IMG;,donext/botleft}');
}

.do_next_pretty_bottom {
	background-repeat: repeat-x;
	background-image: url('{$IMG;,donext/botmid}');
}

.do_next_pretty_bottom_right {
	height: 10px;
	background-repeat: no-repeat;
	background-image: url('{$IMG;,donext/botright}');
}

.control_functions {
	font-weight: bold;
}

.expansive_section {
	overflow: auto;
	padding-right: 1px; /* For non-aligning table borders */
}

#tree_list__root_tree_list {
	padding-bottom: 4px;
}

.ajax_tree_list_loading {
	padding: 80px;
	text-align: center;
}

.tree_list_highlighted a, .tree_list_nonhighlighted a {
	background-color: white;
	color: black;
}

.tree_list_highlighted a {
	font-weight: bold;
}

.tree_list_nonhighlighted a {
}

.block_no_entries {
	font-size: 0.85em;
	margin: 1em;
}

.confirm_area_wrap {
	margin-bottom: 10px;
}

.comcode_errored {
	background-color: #fff2f2; /* {$,wizard, 95% W/B + 5% FF0000} */
	padding: 5px 0;
}

/*
=========================
==With Loaded meanings===
=========================
*/

.autocomplete { /* {$,Membership of this class is used as a tag to allow form autocompletion} */
}

.xhtml_validator_off { /* {$,Membership of this class is used as a tag to turn off the XHTML-validator} */
	display: inline-block; /* To stop it breaking text-align: center */
	width: 100%;
}

.img_thumb { /* {$,Membership of this class is used as a tag to turn on the nereid blend effect} */
	opacity: 0.7;
}

.textarea_scroll { /* {$,Turns off word-wrapping for a textarea: this has to be done using Javascript so that the invalid 'wrap' property isn't written into the XHTML} */
}

body .accessibility_hidden { /* {$,Contents should be made visible (or interpreted) for accessibly representation but hidden for normal visual display} */
	/* Shift it out of the viewport */
	position: absolute;
	top: -256000px;
	left: 0;
	display: block; /* stops browser bugs where it interacts with the layout flow incorrectly */
}

.non_accessibility_redundancy { /* {$,Contents should be skipped by screen readers} */
	{+START,IF,{$MOBILE}}
		display: none;
	{+END}
}

.dequirk, .dequirk_w, .dequirk_h { /* {$,Make a special effort for this to work right in IE quirks mode} */
}

.scale_down { /* {$,Membership of this class is used as a tag to turn on image scaling} */
	max-width: 100%;
	box-sizing: border-box;
}

/*
=========================
=====Reusable Styles=====
=========================
*/

table.scrollable_inside {
	table-layout: fixed; /* {$,for permission setting stuff that can scroll off} */
}

.float_surrounder, .float_surrounder_precise, .float_surrounder_hidden {
	width: 100%;
	outline: 0;
}

.float_surrounder_hidden {
	overflow: hidden;
}

.float_surrounder_table_protect {
	padding: 1px;
}

ul.compact_list, ol.compact_list {
	margin: 0;
	padding: 0;
}

ul.compact_list li, ol.compact_list li {
	margin: 0 0 0 17px;
	padding: 0;
}

ul.spaced_list, .spaced_list ul, ol.spaced_list, .spaced_list ol {
	margin: 0;
	padding: 0 !important;
	list-style-type: square;
}

ul.tick_list, ul.tick_list li {
	margin: 0;
	padding: 0;
	list-style-type: none;
}

.spaced_list li {
	margin: 0 0 10px 25px !important;
	padding: 0;
}

input.input_box_label_within {
	color: gray;
}

.comcode_supported {
	font-size: 0.85em;
}

.comcode_button {
	vertical-align: middle;
}

.required_field_warning {
	border: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
	overflow: hidden;
	padding: 5px;
	background-color: #e9dede; /* {$,wizard, 95% (barrier_a hue_to 0) + 5% !W/B} */
	font-weight: bold;
	font-size: 0.85em;
	margin: 28px auto;
	width: {$?,{$MOBILE},96%,11em};
}

.required_star {
	float: right;
	opacity: 0.4;
}

.standard_meta_block {
}

.trinav_left {
	float: left;
	{+START,IF,{$NOT,{$MOBILE}}}
		margin-left: 26px;
	{+END}
	{+START,IF,{$MOBILE}}
		width: 33%;
	{+END}
	text-align: left;
}

.trinav_mid {
	float: left;
	{+START,IF,{$NOT,{$MOBILE}}}
		margin-left: 26px;
	{+END}
	{+START,IF,{$MOBILE}}
		width: 33%;
	{+END}
	text-align: center;
}

.trinav_right {
	float: right;
	{+START,IF,{$NOT,{$MOBILE}}}
		margin-left: 10px;
		margin-right: 26px;
	{+END}
	{+START,IF,{$MOBILE}}
		width: 33%;
	{+END}
	text-align: right;
}

.table_cell_nowrap {
	white-space: nowrap;
}

.toggle_div_title {
	padding: 2px;
}

.toggler_main {
	background-color: #d8dde6; /* {$,wizard, 95% bgcol + 5% !W/B} */
	border-collapse: collapse;
	border: 1px solid #D8DEE6; /* {$,To break margin collapsing} */
}

.page_icon {
	vertical-align: middle;
	{+START,IF,{$MOBILE}}
		margin-bottom: 5px;
	{+END}
}

.standardbox_title_classic .page_icon {
	margin: -1px 3px 0 0;
}

.button_options_spacer {
	margin-{!en_left}: {$?,{$MOBILE},10,30}px;
}

.horiz_field_sep, .tick_list_spacer {
	padding-{!en_left}: 30px;
}

span.long_space {
	padding-{!en_left}: 30px;
	display: inline-block;
}

hr.long_break {
	margin: 20px 0;
}

.centered_inline_block {
	text-align: center;
}

.inline_block {
	text-align: {!en_left};
	display: inline-block;
}

.inline_block .wide_table_wrap { /* Fixes Firefox bug */
	overflow-x: visible;
	overflow-y: visible;
}

.quite_wide_field {
	width: 88%;
}

{+START,IF,{$NOT,{$MOBILE}}}
	.sliverised_page {
		padding: 0 20%;
	}
{+END}

.sliverised_page table {
	text-align: center;
}

.nothing_here, .more_here {
	font-size: 0.9em;
	padding-{!en_left}: 15px;
	margin-{!en_left}: 10px;
	background-image: url('{$IMG;,edited}');
	background-position: {!en_left} 4px;
	background-repeat: no-repeat;
}

.staff_actions {
	margin-top: 2em;
	font-size: 0.85em;
	{+START,IF,{$MOBILE}}
		border: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
	{+END}
}

.staff_actions a {
	white-space: nowrap !important;
}

.bookmarks_menu_box {
	width: 320px;
}

.edited {
	font-size: 0.85em;
	padding-{!en_left}: {$?,{$MOBILE},0.7,2}em;
	font-style: italic;
}

.edited_block {
	padding-top: {$?,{$MOBILE},10,30}px;
}

.category_list {
	margin: 0;
	padding: 0 0 0 20px;
	overflow: auto;
	zoom: 1;
}

.category_entry {
	padding: 6px 0;
	margin: 6px 0;
	clear: both;
	overflow: hidden;
	width: 100%;
}

.category_entry a img {
	max-width: 150px;
}

.category_entry + .category_entry {
	border-top: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
}

.category_entry a {
	font-size: 1.1em;
}

.category_entry .associated_details {
	margin-bottom: 0;
}

.community_block_tagline {
	text-align: center;
	font-size: 0.8em;
}

.global_side .community_block_tagline {
	font-size: 0.9em;
}

.community_block_tagline_splitter {
	background-color: #d8dde6; /* {$,wizard, 95% bgcol + 5% !W/B} */
	margin-top: 20px;
	border-top: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
}

.whitespace {
	width: 100%;
	overflow: auto;
	outline: 0;
	white-space: pre;
}

hr.spaced_rule {
	margin: 20px 0;
}

.special_category_sorter {
	text-align: center;
	margin: 20px auto 0 auto;
	padding: 5px;
}

.special_category_sorter label {
	font-weight: bold;
}

.special_category_sorter br {
	line-height: 1.3em;
}

.block_reduced_size {
	font-size: 0.85em;
}

ul.actions_list {
	padding: 0 0 0 {$?,{$MOBILE},10,40}px;
	margin: 0;
}

.global_side ul.actions_list {
	padding-left: 15px;
}

ul.actions_list li, ul.actions_list_compact li, ul.actions_list_super_compact li {
	padding: 0;
	margin: 0;
	list-style-type: none;
	list-style-image: none;
}

ul.actions_list h4 {
	display: inline;
	line-height: 2em;
}

ul.actions_list_compact {
	padding: 0 0 0 20px;
	margin: 0;
}

ul.actions_list_super_compact {
	padding: 0;
	margin: 0;
}

li.actions_list_strong {
	font-weight: bold;
}

a.poster_member em {
	text-shadow: 2px 2px 2px #8497b3; /* {$,wizard, 50% bordcolor + 50% W/B } */
	padding: 4px 0;
	letter-spacing: 1px;
}

a.poster_member:link, a.poster_member:active, a.poster_member:visited, a.poster_member:hover {
	font-size: 1em;
	font-weight: bold;
	border: 1px dashed #8497b3; /* {$,wizard, 50% bordcolor + 50% W/B } */
	border-left: 0;
	border-right: 0;
	display: block;
	background-color: #f0f3f9; /* {$,wizard, 75% ocf_row2 + 25% W/B }*/
	margin-bottom: 7px;
	text-decoration: none;
	padding: 2px 2px;
}

.post_poster a.poster_member:link, .post_poster a.poster_member:active, .post_poster a.poster_member:visited, .post_poster a.poster_member:hover {
	display: inline-block;
}

a.poster_member:hover {
	border-color: #072d65; /* {$,wizard, 100% bordcolor}*/
	background-color: #f5f8fb; /* {$,wizard, 50% ocf_row2 + 50% W/B }*/ /*50% white over medborder color*/
}

input.buttonhyperlink {
	border-style: none;
	background-color: transparent;
	text-decoration: underline;
	border: 0;
	margin: 0;
	padding: 0;
	cursor: pointer;
	text-align: {!en_left};
}

/* {$,This will push back 100% width elements that would cause CSS-overflows or table-stretches. Input fields do it a lot because they have built in borders. Doesn't happen for drop-downs and buttons} */
.constrain_field {
	padding-{!en_right}: 9px; /* Tested for precision on Firefox */
}

.container_for_wysiwyg {
	width: 98%; /* Fix firefox bug with scrollbars on WYSIWYG */
}

/* {$,Makes a link tag (a) look like it's not anything special (we use these tags as tab points sometimes)} */
.non_link,
.non_link:link,
.non_link:visited,
.non_link:hover,
.non_link:active {
	color: #0d1522 !important; /* {$,wizard, 20% seed + 80% !W/B} */
	text-decoration: none;
	cursor: default;
}

.pulldown_spacer {
	padding-top: 20px;
}

.form_with_gap {
	padding-top: 30px;
}

.aside_info {
	font-style: italic;
}

.button_panel_spaced {
	margin-top: 10px;
}

.button_panel {
	text-align: center;
}

.button_panel_left {
}

.standard_indent {
	padding-{!en_left}: 100px;
}

.mini_indent {
	padding-{!en_left}: 20px;
}

.shunted_button {
	text-align: {!en_right};
}

/* Works around Firefox bug on Windows */
.really_long_table_wrap {
	overflow-x: visible !important;
	overflow-y: visible !important;
}

.variable_table {
	table-layout: auto !important;
}

.variable_table img {
	vertical-align: middle;
}

.wide_table_wrap {
	overflow-x: auto;
	overflow-y: hidden;
}

.wide_table {
	width: 100%;
	{+START,IF,{$NOT,{$MOBILE}}}
		table-layout: fixed;
	{+END}
}

.spaced_table th, .spaced_table td {
	padding: 3px;
}

/* Undo for nested tables from WYSIWYG */
.solidborder table[cellpadding="0"] td, .solidborder table[cellpadding="0"] th {
	padding: 0;
}

.highlighted_table_cell {
	background-color: #c1cee3; /* {$,wizard, 100% lightborder} */
}

.field_name {
	font-weight: bold;
}

.field_secondary_title_left {
	font-style: italic;
}

.nav_mid {
	text-align: center;
	{+START,IF,{$MOBILE}}
		margin: 10px auto 0px;
		width: 100%;
		float: left;
	{+END}
}

.wide_field, .wide_button {
	width: 100%;
}

input[type="reset"].wide_button, input[type="reset"].button_micro, input[type="reset"].button_page, input[type="reset"].button_pageitem,
input[type="submit"].wide_button, input[type="submit"].button_micro, input[type="submit"].button_page, input[type="submit"].button_pageitem,
input[type="button"].wide_button, input[type="button"].button_micro, input[type="button"].button_page, input[type="button"].button_pageitem,
button.wide_button, button.button_micro, button.button_page, button.button_pageitem
{
	-webkit-transition: opacity 0.5s linear;
	-moz-transition: opacity 0.5s linear;
	-o-transition: opacity 0.5s linear;
	display: inline-block;
	border: none;
	cursor: pointer;
	border: 1px solid #072d65; /* {$,wizard, 100% bordcolor}*/
	background-color: #5a85c5; /* {$,wizard, 100% lgradcolor} */
	color: #ffffff; /* {$,wizard, 100% W/B} */
	border-radius: 6px 6px 6px 6px;
	-moz-border-radius: 6px;
	background-image: url('{$IMG;,standardboxes/title_gradient}');
	opacity: 0.85;
	text-shadow: 1px 1px 1px #000000; /* {$,wizard, 100% !W/B} */
	margin: 0 2px;
	overflow: visible; /* stops button padding on IE7 */
}

.button_pageitem_tall {
	background-image: none !important;
}

input[type="reset"].button_micro, input[type="submit"].button_micro, input[type="button"].button_micro, button.button_micro
{
	padding: 0 3px 1px 3px !important;
	opacity: 1.0; /* Needed for Opera */
}

input[type="reset"].wide_button, input[type="submit"].wide_button, input[type="button"].wide_button, button.wide_button, input[type="submit"].button_pageitem, input[type="button"].button_pageitem, button.button_pageitem
{
	padding: 2px 4px 3px 4px !important;
}

input[type="reset"].button_page, input[type="submit"].button_page, input[type="button"].button_page, button.button_page
{
	padding: 3px 5px 4px 5px !important;
	min-width: {$?,{$MOBILE},5.8,9.8}em;
}

input[type="reset"].wide_button:hover, input[type="reset"].button_micro:hover, input[type="reset"].button_page:hover, input[type="reset"].button_pageitem:hover,
input[type="submit"].wide_button:hover, input[type="submit"].button_micro:hover, input[type="submit"].button_page:hover, input[type="submit"].button_pageitem:hover,
input[type="button"].wide_button:hover, input[type="button"].button_micro:hover, input[type="button"].button_page:hover, input[type="button"].button_pageitem:hover,
button.wide_button:hover, button.button_micro:hover, button.button_page:hover, button.button_pageitem:hover
{
	opacity: 1.0;
}

input[type="reset"].wide_button:disabled, input[type="reset"].button_micro:disabled, input[type="reset"].button_page:disabled, input[type="reset"].button_pageitem:disabled,
input[type="submit"].wide_button:disabled, input[type="submit"].button_micro:disabled, input[type="submit"].button_page:disabled, input[type="submit"].button_pageitem:disabled,
input[type="button"].wide_button:disabled, input[type="button"].button_micro:disabled, input[type="button"].button_page:disabled, input[type="button"].button_pageitem:disabled,
button.wide_button:disabled, button.button_micro:disabled, button.button_page:disabled, button.button_pageitem:disabled
{
	opacity: 0.4 !important;
	cursor: default;
}

.float_separation {
	padding-{!en_right}: 10px;
}

.hide_button {
	vertical-align: middle;
	-webkit-transition: opacity 0.2s linear !important;
	-moz-transition: opacity 0.2s linear !important;
	-o-transition: opacity 0.2s linear !important;
	outline: 0;
	font-weight: bold;
}

{+START,IF,{$NOT,{$MOBILE}}}
	.hide_button_spacing {
		padding-top: 20px;
	}
{+END}

.expanding_page {
	padding-bottom: 500px;
}

.inline_image {
	vertical-align: top !important;
}

.inline_image_2 {
	vertical-align: middle !important;
}

.inline_image_3 {
	vertical-align: baseline !important;
}

.inline_image_4 {
	margin-top: -4px !important;
}

.proceed_button {
	text-align: center;
	padding: 15px 0; /* Can't be margin, as in Firefox it can collapse below the body */
	margin: 0;
}

.global_side .proceed_button {
	padding: 5px 0;
}

div.proceed_button_left {
	text-align: {!en_left};
}

div.proceed_button_left_2 {
	text-align: {!en_left};
	margin-{!en_left}: -20px;
}

.mini_proceed_button {
	padding-top: 20px;
}

.important_notification, .error_marker {
	color: #d91522; /* {$,red_highlights, 80% FF0000 + 20% seed} */
	font-weight: bold;
}

.arrow_ruler {
	text-align: center;
}

.tiny_linebreak {
	line-height: 0.5em;
}

.tiny_para {
	margin: 0.5em 0;
}

.associated_details {
	font-size: 0.8em;
}

/* {$,Used for divs that need to be very close together (vertically)} */
.compact_spacing {
	margin-bottom: 2px;
	padding-bottom: 2px;
}

.associated_breadcrumbs {
	font-size: 0.8em;
	color: #123d7b; /* {$,a.link, 73% (seed sat_to 85) + 27% !W/B} */
}

.associated_caption {
	font-size: 0.8em;
	margin: 5px;
	font-weight: normal;
}

.dottedborder .associated_caption {
	font-size: 0.87em;
}

.associated_link_to_small {
	font-size: 0.8em;
}

.global_side .associated_link_to_small {
	font-size: 0.9em;
}

.red_alert {
	color: #d91522; /* {$,red_highlights, 80% FF0000 + 20% seed} */
	font-weight: bold;
}

.highlight_red {
	color: red;
}

.up_alert {
	text-transform: uppercase;
}

.not_too_tall {
	max-height: 300px;
	overflow: auto;
}

th.meta_data_title {
	font-weight: bold !important;
}

.gallery_media_full_expose {
	overflow: hidden;
	width: 100%;
	outline: 0;
	margin: {$?,{$MOBILE},1,3}em 0;
	text-align: center;
	position: relative;
}

.gallery_media_full_expose img, .img_thumb {
	border: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
	-webkit-box-shadow: 3px 3px 10px #6b81a1; /* {$,wizard, 100% medborder.border} */
	-moz-box-shadow: 3px 3px 10px #6b81a1; /* {$,wizard, 100% medborder.border} */
	box-shadow: 3px 3px 10px #6b81a1; /* {$,wizard, 100% medborder.border} */
	max-width: 100%;
	box-sizing: border-box;
}

/*
=========================
====Core interfaces======
=========================
*/

.inline {
	display: inline;
}

.left {
	float: {!en_left};
}

.right {
	float: {!en_right};
}

.br_space {
	margin-bottom: 1em;
}

.question_ui_buttons {
	text-align: center;
	margin-top: 15px;
}

.sp_header, .view_header {
	vertical-align: bottom;
}

.ocp_tooltip {
	font-size: 1em;
	padding: 3px;
	background-color: #f5f7fa; /* {$,wizard, 5% seed + 95% W/B} */
	border: 1px solid #4b5a71; /* {$,wizard, 70% medborder.border + 30% !W/B} */
	z-index: 1000;
	opacity: 0.9;
	word-wrap: break-word;
}

.ocp_tooltip img {
	max-width: 100%;
}

.ocp_tooltip .shunted_button {
	display: none;
}

.ocp_tooltip .whitespace {
	max-height: 5em;
	overflow: auto;
}

.ocp_tooltip .standardbox_links_classic {
	display: none;
}

.tooltip_img {
	position: absolute;
	right: 3px;
	top: 3px;
}

.ocp_tooltip h2 {
	margin-top: 0;
}

.ocp_tooltip a, .ocp_tooltip a:visited, .ocp_tooltip a:link, .ocp_tooltip a:active, .ocp_tooltip a:hover {
	text-decoration: none !important;
	color: inherit !important;
}

.tooltip_fields {
	border-collapse: collapse;
	font-size: 0.85em;
}

.tooltip_fields th {
	border-right: 1px solid #4b5a71; /* {$,wizard, 70% medborder.border + 30% !W/B} */
	font-weight: bold !important;
	padding-right: 1em;
}

.tooltip_fields td {
	padding-left: 1em;
}

.diff del {
	color: red;
}

.diff ins {
	font-weight: bold;
	text-decoration: none;
}

.field_checkbox_description {
	margin-top: -16px;
	margin-{!en_left}: 25px;
}

.form_field_name {
	margin: 4px;
	display: inline-block;
}

.input_huge_field {
}

.password_strength {
	float: right;
	width: 100px;
	border: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
	display: none;
}

.password_strength_inner {
	height: 1em;
	width: 0px;
}

.input_colour, .input_list, .input_line, .input_integer,
.input_author, .input_username, .input_colour, .input_email, .input_codename,
.input_tick, .input_float, .input_text, .input_upload, .input_radio {
}

.input_colour_required, .input_list_required, .input_line_required, .input_integer_required,
.input_author_required, .input_username_required, .input_colour_required, .input_email_required, .input_codename_required,
.input_tick_required, .input_float_required, .input_text_required, .input_upload_required {
/*	background-color: # F0D0D6*/
}

.input_erroneous {
	background-color: #ffbfbf !important; /* {$,wizard, 25% FF0000 + 75% FFFFFF} */
}

#enter_the_matrix { /* {$,Used for the permission setting display matrix} */
	width: 100%;
	overflow-x: auto;
	outline: 0;
	padding-bottom: 1px;
}

.form_group {
	margin-bottom: 15px;
}

.form_skip {
	height: 35px;
}

.form_skip div {
	float: {!en_right};
}

.form_skip_with_req_note {
	margin: -52px 0 0 0;
}

.input_error_here {
	padding-bottom: 3px;
	color: #a30000; /* {$,wizard, 70% (barrier_a_required sat_to 100) + 30% !W/B} */
	font-size: 0.9em;
	display: block;
	text-align: center;
	text-shadow: 2px 2px 2px #6b81a1; /* {$,wizard, 100% medborder.border} */
}

.input_compound_ticks {
	margin: -4px 0 -5px -5px;
	white-space: nowrap;
}

.input_compound_tick_first input, .input_compound_tick input {
	margin-bottom: 0px;
}

.input_compound_tick {
	margin-{!en_left}: -1px;
	border-{!en_left}: 1px dotted #6b81a1; /* {$,wizard, 100% medborder.border} */
}

.input_compound_tick, .input_compound_tick_first {
	padding: 8px;
	float: {!en_left};
	font-size: 0.9em;
	vertical-align: middle;
}

.people_list {
	background-color: #d4e0f1; /* {$,wizard, 17% (seed sat_to 100) + 83% W/B} */
	color: #0d1522; /* {$,wizard, 20% seed + 80% !W/B} */
	width: auto;
}

.members_viewing {
	padding: 4px;
	text-indent: 25px;
	padding-{!en_left}: 0;
}

.ocf_topic_0 .members_viewing {
	border-top: 0;
}

.post .post_title {
	font-weight: bold;
	padding-left: 0;
	margin-bottom: 0.2em;
}

.post .post_avatar {
	float: right;
	margin: 10px 0 0 20px;
	width: 60px;
}

.post .post_subline {
	margin-bottom: 1em;
	font-size: 0.8em;
}

.post .post_poster {
	font-weight: bold;
}

.post .post_time {
}

.post .post_action_link {
}

.post .post_thread_children {
	margin-top: 1em;
	{+START,IF,{$MOBILE}}
		margin-left: 7px;
	{+END}
	{+START,IF,{$NOT,{$MOBILE}}}
		margin-left: 20px;
	{+END}
}

.post .ocf_post_buttons {
	margin-top: 1.3em;
}

.ocf_post_buttons a {
	opacity: 0.0;
	-webkit-transition-property : opacity;
	-webkit-transition-duration : 0.5s;
	-moz-transition-property : opacity;
	-moz-transition-duration : 0.5s;
	-o-transition-property : opacity;
	-o-transition-duration : 0.5s;
	transition-property : opacity;
	transition-duration : 0.5s;
}

.ocf_post_buttons a[rel="add reply"] {
	opacity: 1.0;
}

.ocf_post_buttons:hover a {
	opacity: 1.0;
}

.post_show_more {
	text-align: center;
	border: 1px dashed #c1cee3; /* {$,wizard, 100% lightborder} */
	border-bottom-left-radius: 40px;
	border-bottom-right-radius: 40px;
	padding: 15px;
	font-weight: bold;
	font-size: 0.85em;
}

.post .post_show_more {
	margin-left: 20px;
}

.radio_list_picture_cat .hide_button img {
	vertical-align: bottom;
}

.radio_list_picture {
	float: {!en_left};
	white-space: nowrap;
	padding: 3px;
	min-width: 40px;
	min-height: 40px;
	font-size: 0.8em;
	min-height: 35px;
	min-width: 35px;
}

#page_running_admin_themes .radio_list_picture {
	float: none;
	margin: 15px;
	border: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
}

.radio_list_picture img {
	max-width: 100px;
}

.results_table {
	font-size: 0.85em;
	margin: 8px 0;
}

.results_table_sorter {
	margin-bottom: 3px;
	max-width: {$?,{$MOBILE},315,400}px;
	float: left;
}

.results_browser_spacing {
	padding: 10px 0;
}

.results_browser {
	float: {$?,{$MOBILE},{!en_left},{!en_right}};
	padding: 0;
	margin: 2px 0 0 0;
/*	max-width: 540px; Looks bad on forumview */
}

.alpha_jumper {
	float: none !important;
	margin-left: 2px !important;
	margin-bottom: 10px !important;
	max-width: 100% !important;
	padding: 3px;
}

.alpha_browser_cont {
	padding: 2px 8px 2px 8px !important;
}

.results_continue, .results_page_num {
	border-{!en_left}: 0;
}

.results_page_num {
	font-weight: bold;
}

.results_browser_per_page {
	{+START,IF,{$NOT,{$MOBILE}}}
		display: inline;
		padding: 0 20px;
	{+END}
	{+START,IF,{$MOBILE}}
		float: left;
	{+END}
}

.results_browser_pages {
	display: inline;
}

/* {$,see also medborder declaration near bottom and .ocf_on declaration above} */
.results_browser a:link,
.results_browser a:visited,
.results_browser a:hover,
.results_browser a:active,
.results_browser span,
.results_launcher a:link,
.results_launcher a:visited,
.results_launcher a:hover,
.results_launcher a:active,
.results_launcher span {
	display: inline-block;
	text-decoration: none;
	margin-top: 0;
	{+START,IF,{$NOT,{$MOBILE}}}
		margin-{!en_left}: -1px;
	{+END}
}
.results_browser a:hover,
.results_launcher a:hover {
	background-color: #d9e1ee; /* {$,wizard, 20% seed + 80% W/B} */
}

.results_browser a:link,
.results_browser a:visited,
.results_browser a:hover,
.results_browser a:active,
.results_browser span,
.results_launcher a:link,
.results_launcher a:visited,
.results_launcher a:hover,
.results_launcher a:active,
.results_launcher span {
	padding: 2px {$?,{$MOBILE},10,5}px;
}

.results_launcher a:link,
.results_launcher a:visited,
.results_launcher a:hover,
.results_launcher a:active,
.results_launcher span {
	padding: 0 3px;
}

.results_launcher {
	font-size: 0.8em;
	display: inline;
	padding-{!en_left}: 20px;
}

.index_page_fancier_page_pre {
	margin-bottom: 15px;
}

.index_page_fancier_page_post {
	margin-top: 15px;
}

{+START,IF,{$NOT,{$MOBILE}}}
	.index_page_fancier_page_entries {
		margin-{!en_left}: 30px;
	}
{+END}

.index_page_fancier_entry {
	margin: 3px;
	padding: 3px;
}

.index_page_fancier_entry_link {
	font-weight: bold;
	margin-bottom: 0.3em;
}

.index_page_fancier_entry_count {
	font-size: 0.8em;
	font-weight: normal;
}

.index_page_fancier_entry_description {
	font-size: 0.8em;
	margin-{!en_left}: 1.3em;
}

#splurgh {
	font-weight: bold;
}

#splurgh ul {
	list-style: none;
	margin-{!en_left}: 0;
	padding-{!en_left}: 0;
	font-size: 1.5em;
}

#splurgh li {
	margin-{!en_left}: 0;
	padding-{!en_left}: 0;
}

#splurgh ul ul {
	list-style: circle;
	font-size: 0.9em;
	padding-top: 6px;
}

#splurgh li li {
	margin-{!en_left}: 40px;
	padding-{!en_left}: 0;
}

#splurgh ul ul ul {
	font-size: 0.8em;
}

#splurgh ul ul ul ul {
    font-size: 1em;
}

.captcha {
	font-size: 0.8em;
	margin-bottom: 3px;
}

.captcha a {
	float: {!en_right};
	margin: 10px 0 0 5px;
}

/*
=========================
========Site-Map=========
=========================
*/

ul.sitemap {
	list-style-type: none;
	list-style-image: none;
	margin-left: 0;
	padding-left: 0;
}

ul.sitemap ul {
	margin-left: 0;
	padding-left: 0;
}

ul.sitemap li {
	margin-top: 2em;
	font-weight: bold;
	font-size: 1.2em;
	margin-left: 0;
	padding-left: 0;
}

ul.sitemap li li {
	margin-top: 0.5em;
	font-weight: normal;
	font-size: 0.9em;
	margin-left: 2em;
	padding-left: 0;
}

/*
=========================
=========Comcode=========
=========================
*/

.shocker {
	text-align: right;
	width: 100%;
	font-size: 1.2em;
}

.shocker_left {
	float: left;
	font-weight: bold;
}

.shocker_right {
}

.comcode_snapback {
	text-align: {!en_right};
	font-size: 0.7em;
}

.comcode_overlay {
	padding: 15px;
	margin: 0;
	background-color: #fafbfd; /* {$,code_content, 25% ocf_row2 + 75% W/B} */
	border: 1px solid #7f9ac5; /* {$,wizard, 68% seed + 32% W/B} */
}

.comcode_overlay_main {
	margin-bottom: 3em;
}

.comcode_overlay_dismiss {
	text-align: center;
	position: absolute;
	bottom: 0;
	margin-bottom: 0.5em; /* For IE6 */
	width: 90%;
}

.comcode_code_wrap {
	width: 100%;
	overflow-x: auto;
}

/* {$,.comcode_quote is used where the [quote] tag is parsed.} */
/* {$,.comcode_code is used where the [code] tag is parsed.} */
.comcode_quote, .comcode_code, .comcode_hide {
	margin: 15px;

	/* To prevent horizontal overlapping with floats */
	outline: 0;
}
.comcode_quote, .comcode_code {
	overflow: auto;
}
.comcode_hide {
	overflow: hidden;
}

.comcode_quote_h4,
.comcode_code_h4 {
	border: 1px solid #7f9ac5; /* {$,wizard, 68% seed + 32% W/B} */
	padding: 4px;
	margin-bottom: 0;
	background: #8ea6cb url('{$IMG;,quote_gradient}') repeat-y; /* {$,comcode_code_h4, 60% seed + 40% W/B} */
}

.comcode_quote_content,
.comcode_code_content {
	border: 1px solid #7f9ac5; /* {$,wizard, 68% seed + 32% W/B} */
	display: block;
	padding: 5px;
	margin-{!en_left}: 8px;
	background-color: #fafbfd; /* {$,code_content, 25% ocf_row2 + 75% W/B} */
	color: #3f3f3f; /* {$,wizard, 25% code_content + 85% !W/B} */
	overflow: auto;
}

.comcode_quote_content_titled {
	border-top: 0;
}

.comcode_code_content {
	font-family: 'Courier New', 'Courier', monospace;
	font-size: 1.1em;
	border-top: 0;
	white-space: nowrap;
}

.hit_counter {
	font-family: 'Courier New', 'Courier', monospace;
	font-size: 1.5em;
}

.hit_counter, .hit_counter div {
	display: inline-block;
}

.comcode_code_scroll {
	max-height: 300px;
}

.comcode_highlight {
	font-weight: bold;
	color: #d91522; /* {$,wizard, 100% red_highlights} */
	background-color: #ffffcc; /* {$,orange_highlights,100% #ffffcc} */
}

.cedi_link, .comcode_exp_ref {
	color: #444649; /* {$,wizard, 30% sb_color + 70% !W/B} */
	font-size: 0.85em;
}

.comcode_exp_ref a {
	background-image: url('{$IMG;,arrow_box}') !important;
}

.cedi_link a {
	background-image: url('{$IMG;,cedi_link}') !important;
}

.comcode_exp_ref a, .cedi_link a {
	padding-{!en_right}: 17px !important;
	background-repeat: no-repeat !important;
	background-position: 100% 30% !important;
}

.comcode_exp_ref a:hover {
	background-image: url('{$IMG;,arrow_box_hover}') !important;
}

.cedi_link a:hover {
	background-image: url('{$IMG;,cedi_link_hover}') !important;
}

.comcode_exp_ref a:hover, .cedi_link a:hover {
	padding-{!en_right}: 17px !important;
	background-repeat: no-repeat !important;
	background-position: 100% 30% !important;
}

.comcode_exp_thumb {
	background-color: #eaeff6; /* {$,wizard, 100% ocf_row2} */
	width: 10%;
	padding: 0;
	margin: 5px;
	margin-{!en_left}: 0;
}

.comcode_exp_thumb td {
	border: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
}

.comcode_exp_thumb p {
	color: #325180; /* {$,wizard, 76% seed + 24% !W/B} */
	font-size: 0.8em;
	padding: 2px;
	margin: 0;
	margin-bottom: 3px;
}

.comcode_exp_thumb img {
	margin: 1px;
}

.comcode_concept_inline, a.comcode_concept_inline:link, a.comcode_concept_inline:visited, a.comcode_concept_inline:hover, a.comcode_concept_inline:active {
	border-bottom: 1px dashed #325180; /* {$,wizard, 76% seed + 24% !W/B} */
	display: inline-block;
}

.comcode_concepts {
	font-size: 0.85em;
	border: 1px solid #bdcbe1; /* {$,wizard, 35% seed + 65% W/B} */
	background-color: #eaeff6; /* {$,wizard, 100% ocf_row2} */
	width: 80%;
	margin: 0 auto;
}

.comcode_concepts_header {
	font-weight: bold;
	text-align: center;
	background-color: #a2b6d5; /* {$,wizard, 60% sb_color + 40% seed} */
	color: #313740; /* {$,wizard, 30% th.bgcolor + 70% !W/B} */
	height: 1.8em;
}

.comcode_concepts_title {
	background-image: url('{$IMG;,checklist/checklist1}');
	background-repeat: no-repeat;
	background-position: 1px 0;
	vertical-align: top;
	text-indent: 14px;
	margin: 0;
}

.comcode_concepts_content {
	padding-bottom: 0.8em;
}

.comcode_table_of_contents {
	border: 1px solid #bdcbe1; /* {$,wizard, 35% seed + 65% W/B} */
	background-color: #eaeff6; /* {$,wizard, 100% ocf_row2} */
	display: inline-block;
	padding-{!en_right}: 10px;
	white-space: nowrap;
	font-size: 0.9em;
}

.search_result .comcode_table_of_contents {
	display: none;
}

.comcode_table_of_contents ol {
	list-style-position: inside;
	padding-{!en_left}: 12px;
	margin: 0;
}
.comcode_table_of_contents li {
	margin: 0;
	padding: 0;
}

.comcode_table_of_contents a {
	margin: 0;
}

.comcode_table_of_contents_title {
	text-align: center;
	color: #444649; /* {$,wizard, 30% sb_color + 70% !W/B} */
	margin: 3px;
	font-weight: bold;
}

.comcode_italic {
	font-style: italic;
}

.comcode_bold {
	font-weight: bold;
}

.comcode_underline {
	text-decoration: underline;
}

.comcode_strike {
	text-decoration: line-through;
}

.image_fader_box {
	position: relative;
	border: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
	display: inline-block;
}

.image_fader_box img {
	display: block;
}

.carousel {
	overflow: hidden;
	width: 100%;
	white-space: nowrap;
	position: relative;
}

.carousel .img_thumb {
	max-width: 140px;
}

.carousel .move_left, .carousel .move_right {
	min-height: 16px;
	width: 17px;
}

.carousel .move_left {
	margin-right: 20px;
	padding-right: 5px;
	float: left;
	background: url('{$IMG;,carousel/button_left}') left center no-repeat;
	border-right: 1px dotted #6b81a1; /* {$,wizard, 100% medborder.border} */
}

.carousel .move_left_hover {
	background-image: url('{$IMG;,carousel/button_left_hover}');
}

.carousel .move_right {
	margin-left: 20px;
	padding-left: 5px;
	float: right;
	background: url('{$IMG;,carousel/button_right}') right center no-repeat;
	border-left: 1px dotted #6b81a1; /* {$,wizard, 100% medborder.border} */
}

.carousel .move_right_hover {
	background-image: url('{$IMG;,carousel/button_right_hover}');
}

.carousel .main {
	overflow: hidden;
}

.comcode_section_controller {
	padding-top: 10px;
	margin-bottom: 20px;
}

{+START,IF,{$NOT,{$MOBILE}}}
	.attachment {
		min-width: 450px;
		margin: 1em 0;
		border: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
	}

	.attachment legend {
		border: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
		padding: 0.15em 0.3em;
		font-size: 0.9em;
		font-style: italic;
	}
{+END}

.attachment_details {
	margin-top: 8px;
}

.attachment_left {
	float: left;
	margin: 0 15px 5px 0;
}

.attachment_right {
	float: right;
	margin: 0 0 5px 15px;
}

.attachment_left .attachment, .attachment_right .attachment {
	width: 200px;
}

.attachment_action {
	font-size: 0.8em;
}

.attachment_action a {
	font-weight: bold;
}

.attachment_img {
	max-width: 100%;
}

.ticker {
	margin: 0 auto;
	height: 15px;
	white-space: nowrap;
	overflow: hidden;
	text-align: left;
}

/*
=========================
========Feedback=========
=========================
*/

.trackback_inside {
	white-space: nowrap;
}

.trackback_result {
	padding: 5px;
}

.no_trackbacks {
	margin-top: 0.68em;
}

.RATING_BOX .rating_inner {
	text-align: center;
}

.RATING_INLINE_DYNAMIC .rating_inner, .RATING_INLINE_DYNAMIC form {
	display: inline;
}

.post_action_link .RATING_INLINE_DYNAMIC {
	padding-left: 20px;
}

.rating_inner {
	white-space: nowrap;
}

.rating_inner img {
	cursor: pointer;
}

.addtocart {
	width: 100px;
	height:34px;
	padding-top: 10px;
}

.trackbacks {
	width: {$?,{$MOBILE},100%,14em};
	margin-top: 1em;
	margin-left: 1em;
}

.ratings {
	width: {$?,{$MOBILE},100%,10em};
	margin-top: 1em;
}

{+START,IF,{$NOT,{$MOBILE}}}
	.lined_up_boxes .ratings, .lined_up_boxes .trackbacks {
		margin-top: 0;
	}

	.lined_up_boxes .right {
		margin-left: 1em;
	}

	.lined_up_boxes .left {
		margin-right: 1em;
	}
{+END}

{+START,IF,{$MOBILE}}
	.lined_up_boxes .right {
		width: 100%;
	}

	.lined_up_boxes .left {
		width: 100%;
	}
{+END}

.ratings .standardbox_spaced {
	padding: 0 0 5px 5px;
}

.highlighted_post {
	background-color: #fafbfd; /* {$,code_content, 25% ocf_row2 + 75% W/B} */
	padding: 15px;
	border: 1px dotted #6b81a1; /* {$,wizard, 100% medborder.border} */
	{+START,IF,{$NOT,{$MOBILE}}}
		margin-right: 70px;
	{+END}
}

#comments_form .standardbox_wrap_internal {
	margin: 0;
	border: 0;
}

#comments_posting_form_outer .attachments {
	text-align: {!en_left};
	padding: 5px;
}

{+START,IF,{$MOBILE}}
	.contact-form { width: 100%; outline: 0; overflow: hidden; font-size: 0.85em; font-weight: bold; }
	.contact-form ul { margin: 0; padding: 10px; }
	.contact-form li { list-style: none; float: left; width: 100%; margin: 5px 0; }
	.contact-form li span { width: 150px; display: block; float: left; }
	.contact-form li span b { font-size: 0.75em; }
	.contact-form li .text-input { float: left; width: 265px; border: 1px solid #072d65; height: 24px; } /* {$,wizard, 100% bordcolor}*/
	.contact-form li .text-input1 { float: left; width: 265px; border: 1px solid #072d65; height: 156px; } /* {$,wizard, 100% bordcolor}*/
	.comments_posting_form_outer .button_pageitem { float: left; }
{+END}

.comments_posting_form_inner {
	text-align: {!en_left};
	padding: 0px;
	margin: 0 auto;
	width: {$?,{$MOBILE},100%,525}px;
	{+START,IF,{$MOBILE}}
		overflow: hidden;
		outline: 0;
	{+END}
}

.comments_posting_form_inner textarea {
	color: #94979d; /* {$,wizard, 65% bgcol + 35% !W/B} */
}

.comments_posting_form_inner table {
	border-collapse: collapse;
}

.comments_posting_form_end {
	overflow: hidden;
	{+START,IF,{$MOBILE}}
		margin: 4px 20px 10px 0px;
		padding: 0;
		text-align: center;
	{+END}
	{+START,IF,{$NOT,{$MOBILE}}}
		margin-left: 160px;
	{+END}
}

{+START,IF,{$MOBILE}}
	.comments_posting_form_end .proceed_button button {
		float: none;
	}
{+END}

.comments_captcha img, .comments_captcha iframe, .comments_captcha input {
	margin: 0 5px 2px 5px;
	vertical-align: middle;
}

.comments_captcha {
	width: 200px;
	margin: 20px auto 0 auto;
	font-size: 0.85em;
	text-align: center;
}

.comments_posting_form_inner th {
	font-weight: bold !important;
	padding: 3px 15px 3px 0;
	border-right: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
}

.comments_posting_form_inner td {
	padding-left: 15px;
}

.comments_posting_form_emoticons {
	float: {!en_left};
	width: 120px;
	padding-{!en_right}: 5px;
	text-align: center;
	padding-top: 5px;
	font-size: 0.8em;
}

.comments_posting_form_emoticons p {
	margin-bottom: 0;
}

.comments_posting_form_links {
	text-align: right;
	font-size: 0.85em;
	font-weight: normal;
}

.reviews_average {
	font-size: 0.8em;
	opacity: 0.7;
}

.inline_wip_message {
	background-color: #F2F5F9; /* {$,wizard, 80% ocf_row2 + 20% W/B}*/
	padding: 4px;
	margin: 0;
	border: 1px solid #EBE773; /* {$,wizard, 100% EBE773} */ /* {$,Intentionally redish} */
	font-size: 0.9em;
}

#global_zones .inline_wip_message {
	background-color: #426aa9; /* {$,wizard, 100% seed} */
}

.inline_wip_message img {
	float: {!en_left};
}

.inline_wip_message p {
	margin: 1px 0 0 28px;
}

/*
=========================
===Specific interfaces===
=========================
*/

div.wysiwyg_color_finder {
	color: #EAEFF5; /* {$,barrier_a, 72% bgcol + 28% W/B} */
}

.banner_side {
	text-align: center;
}

.lonely_preview {
	text-align: center;
}

.preview_iframe {
	width: 100%;
	height: 0;
}

.preview_box {
	margin: 8px 0;
}

{+START,IF,{$MOBILE}}
	.preview_box {
		padding: 209px 33px 159px 31px;
		background: url('{$IMG;,iphone}') no-repeat;
		cursor: crosshair;
	}
	.preview_box_inner {
		overflow: hidden;
		width: 320px;
		height: 355px;
	}
{+END}

.fractional_edit {
	margin: -3px;
	border: 1px dashed #94979d; /* {$,wizard, 65% bgcol + 35% !W/B} */
	padding: 2px;
}

.fractional_edit_nonover {
}

.preview_validation_box {
	width: 34em;
	margin: 10px auto 30px auto;
}

.posting_form_comcode_button {
	float: {!en_right};
	padding-top: 30px;
}

.posting_form_main_comcode_button {
	float: {!en_right};
	padding-top: 10px;
}

.posting_form_sup_link {
	font-size: 0.85em;
}

.posting_form_insert_buttons {
	float: {!en_left};
	background-color: #eaeff6; /* {$,wizard, 100% ocf_row2} */
	margin-left: 9px;
}

.posting_form_wrap_buttons {
	float: {!en_right};
	background-color: #d8dde6; /* {$,wizard, 95% bgcol + 5% !W/B} */
	margin-right: 28px;
}

.posting_form_wrap_buttons, .posting_form_insert_buttons {
	border: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
	padding: 3px 6px;
	margin-top: 3px;
}

.posting_form_insert_buttons span, .posting_form_insert_buttons img, .posting_form_wrap_buttons img, .posting_form_insert_buttons input, .posting_form_wrap_buttons input, .posting_form_wrap_buttons select {
	vertical-align: middle;
}

.posting_form_insert_buttons .divider {
	margin-left: 5px;
	border-left: 1px solid #c1cee3; /* {$,wizard, 100% lightborder} */
	padding-left: 8px;
}

.upload_field_msg {
	white-space: nowrap;
}

.author_defined {
	font-weight: bold;
}

.author_undefined {
}

.comcode_error_help_div {
	{+START,IF,{$NOT,{$MOBILE}}}
		float: {!en_right};
		width: 40%;
		padding: 0 10px;
	{+END}
}

.comcode_error_details_div {
	{+START,IF,{$NOT,{$MOBILE}}}
		width: 55%;
		padding-{!en_left}: 10px;
	{+END}
}

.emoticon_chooser {
	padding: 3px;
}

#panel_top .mini_edit_me {
	display: none;
}

.mini_edit_me {
	font-size: 0.8em;
	text-align: center;
}

.wysiwyg_button {
	font-size: 0.95em;
}

.dynamic_iframe {
	width: 100%;
	height: 900px; /* {$,This is dynamically resized; 900px is referenced from JAVASCRIPT.tpl so don't change it} */
}

.expandable_iframe {
	width: 100%;
}

.form_page_iframe {
	width: 100%;
	height: 0; /* {$,Will be dynamically adjusted} */
}

.zone_choose_inline {
	white-space: nowrap;
}

#i_new_window {
	vertical-align: bottom;
}

blockquote.quotes_block {
	margin: 0;
}

/*
=========================
===========Tabs==========
=========================
*/

.tab_surround {
	border-left: 1px solid;
	border-right: 1px solid;
	border-bottom: 1px solid;
	border-color: #b5b5b5; /* {$,wizard, 100% b5b5b5} */
	padding: 8px;
	margin-left: 1px;
}

.tabs {
	border-left: 0;
	border-right: 0;
	border-top: 0;
	border-bottom: 1px solid;
	border-color: #b5b5b5; /* {$,wizard, 100% b5b5b5} */
	height: 22px;
}

a.tab:link, a.tab:visited, a.tab:hover, a.tab:active {
	text-decoration: none;
}

.tab {
	float: left;
	background: url('{$IMG;,tab}') !important;
	padding: 3px 7px 0 7px !important;
	height: 20px;
	text-align: center;
	cursor: pointer;
}

.tab_active {
	font-weight: bold;
}

.tab:hover {
	text-decoration: underline !important;
}

.tab strong {
	font-weight: normal;
	font-style: italic;
}

.tab_first {
}

.tab_last {
	border-right: 1px solid;
	border-color: #b5b5b5; /* {$,wizard, 100% b5b5b5} */
}

.tab_surround .tab { /* subtabs */
	padding-top: 5px !important;
	height: 18px;
	font-size: 0.88em;
}

/*
=========================
==========Menus==========
=========================
*/

.nl, .nl ul {
	display: block;
	margin: 0;
	padding-{!en_left}: 0;
}

.nl li {
	display: block;
	margin-{!en_left}: 0;
	padding-{!en_left}: 0;
	list-style-type: none;
	list-style-image: none;
}

.menu_type__tree .has_no_img .drawer, .menu_type__popup .has_no_img .drawer {
	background: url('{$IMG;,menus/menu_bullet_expand}') no-repeat 0 5px !important;
}

.menu_type__tree .has_no_img .drawer:hover, .menu_type__popup .has_no_img .drawer:hover {
	background: url('{$IMG;,menus/menu_bullet_expand_hover}') no-repeat 0 5px !important;
}

.has_img a {
	background: none !important;
	padding-{!en_left}: 0 !important;
}

.has_img {
	padding-{!en_left}: 25px !important;
}

.has_img img {
	vertical-align: bottom;
}

.menu_type__dropdown .nlevel .has_img img, .menu_type__popup .has_img img {
	width: 20px;
	max-height: 20px; /* Needed for IE6 PNG hack */
}

.menu_type__tree ul li a, .menu_type__popup ul li a, .menu_type__dropdown ul.nlevel li a { /* ul li added to ensure precedence over ".nl li" selector, whilst not forcing us to use up our only !important */
	display: inline-block;
	padding-{!en_left}: 14px;
}

.menu_type__tree .current a, .menu_type__popup .current a, .menu_type__dropdown .nlevel .current a {
	background: transparent url('{$IMG;,menus/menu_bullet_current}') no-repeat 5px 6px !important;
}

.menu_type__popup .has_img.current a, .menu_type__dropdown .nlevel .has_img.current a {
	background: none !important;
}

.menu_type__tree .non_current a, .menu_type__popup .non_current a, .menu_type__dropdown .nlevel .non_current a {
	background: transparent url('{$IMG;,menus/menu_bullet}') no-repeat 5px 6px;
}

.menu_type__tree .non_current a:hover, .menu_type__popup .non_current a:hover, .menu_type__dropdown .nlevel .non_current a:hover {
	background: transparent url('{$IMG;,menus/menu_bullet_hover}') no-repeat 5px 6px;
}

.menu_type__select li, .menu_type__dropdown .nlevel li {
	padding: 3px 5px !important;
}

.menu_type__tree li, .menu_type__popup li {
	padding: 3px 5px 3px 0 !important;
}

.menu_type__popup .nlevel li , .menu_type__dropdown .nlevel li {
	white-space: nowrap;
}

.global_bottom img {
	-webkit-transition: -webkit-transform 0.5s linear;
	-moz-transition: -moz-transform 0.5s linear;
	-o-transition: -o-transform 0.5s linear;
}

.global_bottom img:hover {/*, .menu_type__dropdown li:hover>img*/
   -webkit-transform: rotate(10deg);
   -moz-transform: rotate(10deg);
}

.menu_type__popup {
	min-width: 150px;
}

.menu_type__dropdown ul.nlevel, .menu_type__popup ul {
	line-height: 1.4em;
	border-top: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
	border-left: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
	border-right: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
}

.menu_type__dropdown ul.nlevel {
	-webkit-box-shadow: 3px 3px 10px #6b81a1; /* {$,wizard, 100% medborder.border} */
	-moz-box-shadow: 3px 3px 10px #6b81a1; /* {$,wizard, 100% medborder.border} */
	box-shadow: 3px 3px 10px #6b81a1; /* {$,wizard, 100% medborder.border} */
}

.menu_type__popup .menu_spacer, .menu_type__popup li, .menu_type__dropdown .nlevel li, .menu_type__dropdown .nlevel .menu_spacer {
	border-bottom: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
	white-space: nowrap; /* Needed for IE6, which would not give enough width on second opening of same menu, due to weird bug */
}

.menu_type__popup .menu_spacer, .menu_type__popup li {
	background-color: #eaeff6 !important; /* {$,mm_c_tab, 100% ocf_row2} */
}

.menu_type__popup li a:link, .menu_type__popup li a:visited, .menu_type__popup li a:active {
	color: #123d7b; /* {$,wizard, 73% (seed sat_to 85) + 27% !W/B} */
}
.menu_type__popup li a:hover {
	color: #9C202F !important; /* {$,wizard, 100% a.hover}*/
}

.menu_type__popup ul ul {
	margin-top: -1px;
}

.menu_type__popup a:link, .menu_type__popup a:visited, .menu_type__popup a:active, .menu_type__dropdown .nlevel a:link, .menu_type__dropdown .nlevel a:visited, .menu_type__dropdown .nlevel a:active {
	text-decoration: none;
}

.menu_type__popup a:hover, .menu_type__dropdown .nlevel a:hover {
	text-decoration: underline;
	cursor: pointer;
}

.menu_type__dropdown .nlevel li, .menu_type__dropdown .nlevel .menu_spacer {
	background-color: #c1cee3; /* {$,wizard, 100% lightborder} */
}

.menu_type__dropdown .nlevel li:hover {
	background-color: #d9e1ee; /* {$,wizard, 20% seed + 80% W/B} */
}

.menu_type__dropdown .nlevel .menu_spacer {
	display: block;
	padding-{!en_right}: 0;
}

.menu_type__dropdown .nlevel, .menu_type__dropdown .nlevel a:active, .menu_type__dropdown .nlevel a:link, .menu_type__dropdown .nlevel a:visited, .menu_type__dropdown .nlevel a:hover {
	color: #0d1522 !important; /* {$,wizard, 20% seed + 80% !W/B} */
}

.menu_type__embossed, .menu_type__top, .menu_type__dropdown {
	overflow: hidden;
	outline: 0;
	zoom: 1; /* IE6 fix, can't use width 100% as we normally would for this */
}

.menu_type__embossed, .menu_type__top, .menu_type__dropdown, .menu_type__embossed li, .menu_type__top li, .menu_type__dropdown li.toplevel {
	background-color: #eaeff6 !important; /* {$,mm_c_tab, 100% ocf_row2} */
}

.menu_type__embossed .current, .menu_type__top .current, .menu_type__dropdown .toplevel.current {
	color: #0d1522; /* {$,wizard, 20% seed + 80% !W/B} */
	background-color: #c2d1e5 !important; /* {$,hover_bg, 93% (mm_c_tab sat_to 15) + 7% !W/B} */
}

.menu_type__embossed a:link, .menu_type__embossed a:visited, .menu_type__embossed a:hover, .menu_type__embossed a:active, .menu_type__top a:link, .menu_type__top a:visited, .menu_type__top a:hover, .menu_type__top a:active {
	text-decoration: none;
}

.menu_type__embossed a:hover, .menu_type__top a:hover, .menu_type__dropdown a.toplevel_link:hover {
	background-color: #c2d1e5 !important; /* {$,hover_bg, 93% (mm_c_tab sat_to 15) + 7% !W/B} */
	-webkit-transition: color,background-color 0.5s linear;
	-moz-transition: color,background-color 0.5s linear;
	-o-transition: color,background-color 0.5s linear;
}

.menu_type__embossed a, .menu_type__top a, .menu_type__dropdown a.toplevel_link {
	display: block;
	padding: 3px 4px 5px 4px !important;
	outline: 0;
}

.menu_type__top a, .menu_type__dropdown a.toplevel_link {
	font-size: 0.9em;
}

{+START,IF,{$NEQ,{$LANG},EN}}
	.menu_type__embossed a, .menu_type__top a, .menu_type__dropdown a.toplevel_link {
		font-size: 0.72em;
	}
{+END}

.menu_type__embossed {
	border-left: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
	border-right: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
	border-bottom: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
}

.menu_type__embossed li {
	border-top: 1px solid #6b81a1; /* {$,wizard, 100% medborder.border} */
}

.menu_type__top, .menu_type__dropdown {
	border-top: 1px solid #0d1522; /* {$,wizard, 20% seed + 80% !W/B} */
	border-bottom: 1px solid #0d1522; /* {$,wizard, 20% seed + 80% !W/B} */
	border-{!en_right}: 1px solid #0d1522; /* {$,wizard, 20% seed + 80% !W/B} */
}

.menu_type__top li, .menu_type__dropdown li.toplevel {
	float: {!en_left};
	border-{!en_left}: 1px solid #0d1522; /* {$,wizard, 20% seed + 80% !W/B} */
	margin-{!en_right}: -1px;
	margin-bottom: 0;
	{+START,IF,{$MOBILE}}
		font-size: 0.8em;
	{+END}
	-webkit-transition: color,background-color 0.5s linear;
	-moz-transition: color,background-color 0.5s linear;
	-o-transition: color,background-color 0.5s linear;
}

.menu_type__top li.last, .menu_type__dropdown li.toplevel.last {
	float: none !important; /* so it eats all space remaining */
	overflow: hidden; /* so it is shunted against it's left-hand neighbours without overlapping */
	margin-{!en_right}: 0 !important; /* as would cause wrapping with the overflow hidden */
	position: relative; {!en_left}: -1px; /* In place of margin-right */
}

.menu_type__top li a, .menu_type__dropdown li.toplevel a {
	min-height: 19px;
	height: auto !important; /* IE6 hack, IE still takes the 19px value due to a bug */
	height: 19px; /* IE6, does not take precedence */
	padding-bottom: 0 !important; /* Otherwise IE6/IE7 doubles it - so is built into height */
}

.menu_type__top li.last a, .menu_type__dropdown li.toplevel.last a {
	border-left: 0 !important; /* IE6 hack */
	border-left: 1px solid #0d1522; /* {$,wizard, 20% seed + 80% !W/B} */
}

.menu_type__top img, .menu_type__dropdown .toplevel_link img {
	margin-top: -2px;
}

.menu_type__top img, .menu_type__dropdown img {
	float: {!en_left};
	padding: 0 8px 0 3px;
}

.menu_type__top .menu_spacer, .menu_type__dropdown li.toplevel.menu_spacer {
	height: 1.15em;
	width: 4em;
	padding: 4px;
	float: {!en_left};
}

.menu_type__tree ul, .menu_type__select ul {
	margin: 2px 0 0 0 !important;
}

.menu_type__tree ul ul {
	padding-{!en_left}: 5px;
}

.menu_type__zone {
	font-size: 0.9em;
	max-height: 15px;
}

.menu_type__zone ul {
	display: inline;
	margin: 0;
	padding: 0;
	{+START,IF,{$MOBILE}}
		overflow:hidden;
		height:auto;
		text-align:center;
	{+END}
}

{+START,IF,{$NEQ,{$LANG},EN}}
	.menu_type__zone ul {
		font-size: 0.85em;
	}
{+END}

.menu_type__zone li {
	display: inline;
	padding: 0;
	list-style-type: none;
	list-style-image: none;
}

.menu_type__zone li * {
	vertical-align: middle;
}

.menu_type__zone .divider {
	color: #bdcbe1; /* {$,wizard, 35% seed + 65% W/B} */
}

#global_zones .menu_type__zone a:link, #global_zones .menu_type__zone a:visited, #global_zones .menu_type__zone a:active {
	color: #edf2f9; /* {$,wizard, 15% zg_top + 85% W/B} */
}

.menu_type__zone a:link, .menu_type__zone a:visited, .menu_type__zone a:active {
	margin-{!en_right}: 1px;
	text-decoration: none;
}

#global_zones .menu_type__zone a:hover {
	color: #ffffff; /* {$,global_zones_hover, 100% W/B } */
}

.menu_type__zone a {
	border-bottom: 1px transparent;
	-webkit-transition: border-bottom-color 0.5s linear;
	-moz-transition: border-bottom-color 0.5s linear;
	-o-transition: border-bottom-color 0.5s linear;
	border-bottom-color: #426aa9; /* {$,wizard, 100% seed} */
}

.menu_type__zone a:hover {
	text-decoration: none;
	border-bottom: 1px dashed;
}

.menu_type__zone .current {
	border-bottom: 1px dashed;
	border-bottom-color: #a5bde1; /* {$,wizard, 75% zg_top + 25% FFFFFF} */
}

.menu_type__zone .current:hover {
	border-bottom: 1px dashed;
	border-bottom-color: #ffffff; /* {$,wizard, 100% global_zones_hover} */
}

.menu_type__zone .menu_spacer {
	padding: 0 3em;
}

.edit_menu_link {
	text-align: {!en_right};
	font-size: 0.8em;
}

.menu_block .edit_menu_link a, #global_zones .edit_menu_link_inline, #panel_top .edit_menu_link_inline, #panel_bottom .edit_menu_link_inline {
	opacity: 0.4;
	-webkit-transition: opacity 0.5s linear;
	-moz-transition: opacity 0.5s linear;
	-o-transition: opacity 0.5s linear;
}
.menu_block:hover .edit_menu_link a, #global_zones:hover .edit_menu_link_inline, #panel_top:hover .edit_menu_link_inline, #panel_bottom:hover .edit_menu_link_inline {
	opacity: 1.0;
}

*>.edit_menu_link_inline {
	display: none;
}

*:hover>.edit_menu_link_inline {
	display: block;
}

.edit_menu_link_inline {
	position: absolute;
	right: 1px;
	z-index: 10000;
}

/*
=========================
=====Screen actions======
=========================
*/

#screen_actions_outer {
	margin: 20px 0;
}

#screen_actions {
	overflow: hidden;
	width: 100%;
}

#screen_actions div {
	margin-{!en_right}: 20px;
	background-repeat: no-repeat;
	float: {!en_left};
}

#screen_actions div a {
	padding-{!en_left}: 20px;
	height: 1.7em;
	display: inline-block;
}

{+START,IF,{$ADDON_INSTALLED,recommend}}
#screen_actions .print {
	background-image: url('{$IMG;,recommend/print}');
}

#screen_actions .recommend {
	background-image: url('{$IMG;,recommend/recommend}');
}

#screen_actions .favorites {
	background-image: url('{$IMG;,recommend/favorites}');
}

#screen_actions .facebook {
	background-image: url('{$IMG;,recommend/facebook}');
}

#screen_actions .twitter {
	background-image: url('{$IMG;,recommend/twitter}');
}

#screen_actions .stumbleupon {
	background-image: url('{$IMG;,recommend/stumbleupon}');
}

#screen_actions .digg {
	background-image: url('{$IMG;,recommend/digg}');
}

#screen_actions .google_plusone {
	margin-top: 1px;
}
{+END}

/*
=========================
====Link type display====
===Based on "Elements"===
==== by Ben Henschel ====
=========================
*/

a[href^="mailto:"] {background: url('{$IMG;,filetypes/email_link}') no-repeat right top; padding: 0 22px 5px 0;}
a[href$=".pdf"], a[href$=".ps"], body div a.pdf_link {background: url('{$IMG;,filetypes/page_pdf}') no-repeat right top; padding: 0 22px 5px 0;}
a[href$=".doc"], a[href$=".docx"], a[href$=".rtf"], body div a.doc_link {background: url('{$IMG;,filetypes/page_doc}') no-repeat right top; padding: 0 22px 5px 0;}
a[href$=".xls"], a[href$=".xlsx"], body div a.xls_link {background: url('{$IMG;,filetypes/page_xls}') no-repeat right top; padding: 0 22px 5px 0;}
a[href$=".ppt"], a[href$=".pptx"], body div a.ppt_link {background: url('{$IMG;,filetypes/page_ppt}') no-repeat right top; padding: 0 22px 5px 0;}
a[href$=".log"], a[href$=".txt"], body div a.txt_link {background: url('{$IMG;,filetypes/page_txt}') no-repeat right top; padding: 0 22px 5px 0;}
a[href$=".odt"], body div a.odt_link {background: url('{$IMG;,filetypes/page_odt}') no-repeat right top; padding: 0 22px 5px 0;}
a[href$=".odp"], body div a.odp_link {background: url('{$IMG;,filetypes/page_odt}') no-repeat right top; padding: 0 22px 5px 0;}
a[href$=".ods"], body div a.ods_link {background: url('{$IMG;,filetypes/page_ods}') no-repeat right top; padding: 0 22px 5px 0;}
a[href$=".rss"], body div a.feed_link {background: url('{$IMG;,filetypes/feed}') no-repeat right top; padding: 0 22px 5px 0;}
a[href$=".torrent"], body div a.torrent_link {background: url('{$IMG;,filetypes/page_torrent}') no-repeat right top; padding: 0 22px 5px 0;}
a[href$=".zip"], a[href$=".gz"], a[href$=".bz2"], a[href$=".tar"], a[href$=".rar"], body div a.archive_link {background: url('{$IMG;,filetypes/page_archive}') no-repeat right top; padding: 0 22px 5px 0;}
a[href$=".asf"], a[href$=".ra"], a[href$=".wma"], a[href$=".wav"], a[href$=".mp3"], a[href$=".ogg"], a[href$=".mid"], a[href$=".mov"], a[href$=".qt"], a[href$=".wmv"], a[href$=".ram"], a[href$=".rm"], a[href$=".avi"], a[href$=".mpg"], a[href$=".mpe"], a[href$=".mpeg"], a[href$=".mp4"], a[href$=".webm"], body div a.media_link {background: url('{$IMG;,filetypes/page_media}') no-repeat right top; padding: 0 22px 5px 0;}
a[target="_blank"] {background: url('{$IMG;,filetypes/external_link}') no-repeat right top; padding-right:10px;}
a[onclick$="window.open"], body div a.external_link {background: url('{$IMG;,filetypes/external_link}') no-repeat right top !important; padding-right:10px !important;}
body a.link_exempt, body link_exempt_wrap a, body a[href*=".php"] {background-image:none; padding:0px;}
body a.link_exempt2 {background-image:none;}
{+START,IF,{$ADDON_INSTALLED,recommend}}
.print_icon {background: url('{$IMG;,recommend/print}') no-repeat left top !important; padding: 0 0 5px 22px !important;}
{+END}

a[title="{!VIRTUAL_ROOT}"]:hover {
	color: #d91522; /* {$,red_highlights, 80% FF0000 + 20% seed} */
}

/*
=========================
=======Print rules=======
=========================
*/

@media print {
	body {
		background: none;
	}

	h1 {
		display: none;
	}

	.wide_table_wrap {
		overflow-y: visible !important;
	}

	.ocf_member_signature .comcode_hide, .button_panel, #screen_actions_outer, .adminzone_search, .global_top, .global_banner, .hide_button, .bottom, .global_side, .mini_edit_me, .control_functions, .staff_actions, .ocf_page_buttons, .ocf_member_bar, .ocf_post_buttons, .ocf_topic_marker, #comments_form, .members_viewing, .member_bar_etc, .ratings, .trackbacks, #news_archive_link {
		display: none;
	}

	#global_zones {
		visibility: hidden;
	}

	#global_middle_ph {
		position: absolute;
		{!en_left}: 0;
		width: auto;
	}
}
